@@ -2,16 +2,13 @@
 #
 # Project    : ipv6calc
 # File       : autogen.sh
-# Version    : $Id: autogen.sh,v 1.15 2011/10/09 07:17:09 peter Exp $
-# Copyright  : 2003-2011 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: autogen.sh,v 1.26 2013/10/20 17:45:10 ds6peter Exp $
+# Copyright  : 2003-2013 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Information: autogeneration of projects with optional features
 
 OPTIONS_CONFIGURE=""
 
-DB_GEOIP="--with-geoip-ipv4-default-file=/var/local/share/GeoIP/GeoIP.dat --with-geoip-ipv6-default-file=/var/local/share/GeoIP/GeoIPv6.dat"
-DB_IP2LOCATION="--with-ip2location-ipv4-default-file=/var/local/share/IP2Location/IP-COUNTRY-SAMPLE.BIN --with-ip2location-ipv6-default-file=/var/local/share/IP2Location/IPV6-COUNTRY.BIN"
-
 LAST=""
 while [ "$1" != "$LAST" ]; do
 	LAST="$1"
@@ -28,20 +25,23 @@ while [ "$1" != "$LAST" ]; do
 		shift
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-geoip"
 		;;
+	    '--geoip-dyn'|'-G')
+		shift
+		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-geoip --with-geoip-dynamic"
+		;;
 	    '--ip2location'|'-i')
 		shift
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-ip2location"
 		;;
-	    '--db'|'-d')
+	    '--ip2location-dyn'|'-I')
 		shift
-		# default database locations
-		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE $DB_GEOIP $DB_IP2LOCATION"
+		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --enable-ip2location --with-ip2location-dynamic"
 		;;
 	    '--disable-db-ieee')
 		shift
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --disable-db-ieee"
 		;;
-	    '--disable-db-ipv6')
+	    '--disable-db-ipv4')
 		shift
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --disable-db-ipv4"
 		;;
@@ -53,18 +53,24 @@ while [ "$1" != "$LAST" ]; do
 		shift
 		OPTIONS_CONFIGURE="$OPTIONS_CONFIGURE --with-geoip-ipv6-compat"
 		;;
+	    '-W')
+		shift
+		EXTRA_CFLAGS="-Werror"
+		;;
 	    '-?'|'-h'|'--help')
 		echo "Supported options:"
-		echo "   -?|-h|--help       : this help"
-		echo "   -n|--no-make       : stop before running 'make'"
-		echo "   -a|--all           : enable GeoIP and IP2Location support"
-		echo "   -g|--geoip         : enable GeoIP support"
-		echo "   -i|--ip2location   : enable IP2Location support"
-		echo "   -d|--db            : enable default GeoIP and IP2Location database locations"
-		echo "   --disable-db-ieee  : disable builtin IEEE database"
-		echo "   --disable-db-ipv4  : disable builtin IPv4 database"
-		echo "   --disable-db-ipv6  : disable builtin IPv6 database"
-		echo "   --geoip-ipv6-compat: enable GeoIP IPv6 compatibility mode"
+		echo "   -?|-h|--help        : this help"
+		echo "   -W                  : use extra CFLAGS=-Werror"
+		echo "   -n|--no-make        : stop before running 'make'"
+		echo "   -a|--all            : enable GeoIP and IP2Location support"
+		echo "   -g|--geoip          : enable GeoIP support"
+		echo "   --geoip-dyn|-G      : switch to dynamic library loading of GeoIP"
+		echo "   -i|--ip2location    : enable IP2Location support"
+		echo "   --ip2location-dyn|-I: switch to dynamic library loading of IP2Location"
+		echo "   --disable-db-ieee   : disable built-in IEEE database"
+		echo "   --disable-db-ipv4   : disable built-in IPv4 database"
+		echo "   --disable-db-ipv6   : disable built-in IPv6 database"
+		echo "   --geoip-ipv6-compat : enable GeoIP IPv6 compatibility mode"
 		exit 1
 	esac
 done
@@ -92,6 +98,7 @@ fi
 echo "*** run: make clean"
 make clean || exit 1
 
+export EXTRA_CFLAGS
 echo "*** run: make"
 make || exit 1
 
@@ -100,4 +107,3 @@ make test || exit 1
 
 echo
 echo "For installing the binaries, type: make install"
-
