@@ -2,10 +2,13 @@
 #
 # Project    : ipv6calc
 # File       : create_ieee_oui_headerfile.pl
-# Version    : $Id: create_ieee_oui_headerfile.pl,v 1.10 2011/10/08 11:50:13 peter Exp $
-# Copyright  : 2002-2011 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: create_ieee_oui_headerfile.pl,v 1.13 2013/04/08 19:34:56 ds6peter Exp $
+# Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Creates a header file out of IEEE/oui.txt
+#
+# Virtual Machine prefixes from:
+# http://www.techrepublic.com/blog/networking/mac-address-scorecard-for-common-virtual-machine-platforms/538
 
 use strict;
 use File::stat;
@@ -15,6 +18,10 @@ my $INFILE;
 
 my $OUTFILE = "dbieee_oui.h";
 
+my $flag_qemu = 0;
+
+my $debug = 0;
+
 $INFILE = shift;
 
 if (! defined $INFILE) { $INFILE = "oui.txt" };
@@ -43,7 +50,7 @@ print OUT qq| * Generated     : $now_string
 
 # print creation date
 my $sb = stat($INFILE);
-print OUT "static const char* libieee_oui_status = \"OUI/" . strftime("%Y%m%d", localtime($sb->mtime)) . "\";\n";
+print OUT "\/\*\@unused\@\*\/ static const char* libieee_oui_status __attribute__ ((__unused__)) = \"OUI/" . strftime("%Y%m%d", localtime($sb->mtime)) . "\";\n";
 
 # Structure
 print OUT qq|
@@ -52,27 +59,42 @@ static const s_ieee_oui libieee_oui[] = {
 |;
 
 
+my ($a, $b, $c);
+my ($t1, $t2, $t3);
+my $oui;
+
 # Data
 my $i = 0;
+my $m = 0;
 while (<IN>) {
 	my $line = $_;
 	chomp $line;
 
+	$i++;
+
 	if ($line =~ /\(hex\)/ ) {
-
-		$i++;
-		print STDERR $i . "\r";
-
-
-		# kill spaces
+		# kill additional spaces
 		$line =~ s/[ \t]+/ /g;
-		#print $line . "\n";
-		my ($t1, $t2, $t3) = split / /, $line, 3;
+		# kill leading spaces
+		$line =~ s/^ *//g;
+		# kill trailing spaces
+		$line =~ s/ *$//g;
+
+		$m++;
+		print STDERR "$m\r" if ($debug == 0);
+
+		print STDERR "$i: $line\n" if ($debug != 0);
+
+		($t1, $t2, $t3) = split / /, $line, 3;
+
+		print STDERR $i . ": t1=$t1 t2=$t2 t3=$t3\n" if ($debug != 0);
 	
-		my ($a, $b, $c) = split /-/, $t1;
+		($a, $b, $c) = split /-/, $t1;
+
+		print STDERR $i . ": a=$a b=$b c=$c\n" if ($debug != 0);
 
 		# shorten OUI string
-		my $oui = uc($t3);
+		$oui = uc($t3);
 
 		# replace '(' ')' '&'
 		$oui =~ s/[\(\)\&\',]/ /ig;
@@ -125,6 +147,42 @@ while (<IN>) {
 		# remove trailling '-'
 		$oui =~ s/-+$//ig;
 
+		# Append information for special OUIs
+		if ($a eq "08" && $b eq "00" && $c eq "27") {
+			# 08:00:27
+			$t3 .= " (possible VirtualBox VM)";
+			$oui .= "-VIRTUAL";
+		} elsif ($a eq "00" && $b eq "03" && $c eq "FF") {
+			# 00:03:FF
+			$t3 .= " (possible Hyper-V, Virtual Server, Virtual PC VM)";
+			$oui .= "-VIRTUAL";
+		} elsif ($a eq "00" && $b eq "1C" && $c eq "42") {
+			# 00:1C:42
+			$t3 .= " (possible Paralles Desktop, Workstation, Server, Virtuozzo VM)";
+			$oui .= "-VIRTUAL";
+		} elsif ($a eq "00" && $b eq "0F" && $c eq "4B") {
+			# 00:0F:4B
+			$t3 .= " (possible Virtual Iron VM)";
+			$oui .= "-VIRTUAL";
+		} elsif ($a eq "00" && $b eq "16" && $c eq "3E") {
+			# 00:16:3E
+			$t3 .= " (possible Xen VM)";
+			$oui .= "-VIRTUAL";
+		} elsif ($a eq "52" && $b eq "54" && $c eq "00") {
+			# 52:54:00
+			$t3 .= " (possible QEMU VM)";
+			$oui .= "-VIRTUAL";
+			$flag_qemu = 1;
+		} elsif ( ($a eq "00" && $b eq "50" && $c eq "56") ||
+			  ($a eq "00" && $b eq "0C" && $c eq "29") ||
+			  ($a eq "00" && $b eq "05" && $c eq "69") ) {
+			# 00:50:56
+			# 00:0C:29
+			# 00:05:69
+			$t3 .= " (possible VMware VM)";
+			$oui .= "-VIRTUAL";
+		};
+
 		# escape "
 		$t3 =~ s/"/\\"/g;
 	
@@ -132,6 +190,13 @@ while (<IN>) {
 	};
 };
 
+
+if ($flag_qemu == 0) {
+	# print missing qemu
+	$a = "52"; $b = "54"; $c = "00"; $t3 = "possible QEMU VM"; $oui = "QEMU-VIRTUAL";
+	print OUT "\t{ 0x" . $a . $b . $c . ", \"$t3\", \"$oui\" },\n";
+};
+
 print OUT qq|
 };
 |;
