@@ -1,12 +1,12 @@
 /*
  * Project    : ipv6calc
- * File       : ipv6calc.c
- * Version    : $Id: ipv6calc.c,v 1.78 2013/05/12 07:34:04 ds6peter Exp $
+ * File       : ipv6calc/ipv6calc.c
+ * Version    : $Id: ipv6calc.c,v 1.102 2013/11/15 07:18:39 ds6peter Exp $
  * Copyright  : 2001-2013 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Central program (main)
- *  This program print out different formats of an given IP(v4/v6) address
+ *  This program print out different formats of an given IP(v4/v6)/MAC address
  */
 
 #include <stdio.h>
@@ -17,9 +17,12 @@
 
 #include "ipv6calc.h"
 #include "libipv6calc.h"
+#include "libipv6calcdebug.h"
 #include "ipv6calctypes.h"
 #include "ipv6calcoptions.h"
+#include "ipv6calcoptions_local.h"
 #include "ipv6calchelp.h"
+#include "ipv6calchelp_local.h"
 
 #include "libipv4addr.h"
 #include "libipv6addr.h"
@@ -47,6 +50,8 @@
 #include "libipv6addr.h"
 #include "../databases/ipv6-assignment/dbipv6addr_assignment.h"
 
+#include "../databases/lib/libipv6calc_db_wrapper.h"
+
 #ifdef SUPPORT_IP2LOCATION
 #include "IP2Location.h"
 
@@ -72,149 +77,11 @@ int input_is_pipe = 0;
 
 /* anonymization default values */
 s_ipv6calc_anon_set ipv6calc_anon_set;
-int mask_ipv4;
-int mask_ipv6;
-int mask_iid;
-int mask_mac;
 
-int  use_ip2location_ipv4 = 0; /* if set to 1, IP2Location IPv4 is enabled by option(s) */
-int  use_ip2location_ipv6 = 0; /* if set to 1, IP2Location IPv6 is enabled by option(s) */
-#ifdef SUPPORT_IP2LOCATION
-#ifdef IP2LOCATION_DEFAULT_FILE_IPV4
-char file_ip2location_ipv4[NI_MAXHOST] = IP2LOCATION_DEFAULT_FILE_IPV4;
-#else
-char file_ip2location_ipv4[NI_MAXHOST] = "";
-#endif
-#ifdef IP2LOCATION_DEFAULT_FILE_IPV6
-char file_ip2location_ipv6[NI_MAXHOST] = IP2LOCATION_DEFAULT_FILE_IPV6;
-#else
-char file_ip2location_ipv6[NI_MAXHOST] = "";
-#endif
-#endif
-
-int  use_geoip_ipv4 = 0; /* if set to 1, GeoIP IPv4 is enabled by option(s) */
-int  use_geoip_ipv6 = 0; /* if set to 1, GeoIP IPv6 is enabled by option(s) */
-#ifdef SUPPORT_GEOIP
-#ifdef GEOIP_DEFAULT_FILE_IPV4
-char file_geoip_ipv4[NI_MAXHOST] = GEOIP_DEFAULT_FILE_IPV4;
-#else
-char file_geoip_ipv4[NI_MAXHOST] = "";
-#endif
-#ifdef GEOIP_DEFAULT_FILE_IPV6
-char file_geoip_ipv6[NI_MAXHOST] = GEOIP_DEFAULT_FILE_IPV6;
-#else
-char file_geoip_ipv6[NI_MAXHOST] = "";
-#endif
-#endif
-
-void printversion(void) {
-	fprintf(stderr, "%s: version %s", PROGRAM_NAME, PACKAGE_VERSION);
-#ifdef SUPPORT_IP2LOCATION
-	fprintf(stderr, " IP2Location");
-#endif
-#ifdef SUPPORT_GEOIP
-	fprintf(stderr, " GeoIP");
-#ifdef SUPPORT_GEOIP_V6
-	fprintf(stderr, " GeoIPv6");
-#endif
-#endif
-#ifdef SUPPORT_DB_IEEE
-	fprintf(stderr, " DB_IEEE");
-#endif
-#ifdef SUPPORT_DB_IPV4
-	fprintf(stderr, " DB_IPV4");
-#endif
-#ifdef SUPPORT_DB_IPV6
-	fprintf(stderr, " DB_IPV6");
-#endif
-	fprintf(stderr, "\n");
-};
-
-void printversion_verbose(void) {
-	printversion();
-	fprintf(stderr, "\n");
-
-#ifdef SUPPORT_DB_IEEE
-	fprintf(stderr, "IEEE database included: %s %s %s\n", libieee_iab_status, libieee_oui_status, libieee_oui36_status);
-#else
-	fprintf(stderr, "IEEE database not included\n");
-#endif
-
-#ifdef SUPPORT_DB_IPV4
-	fprintf(stderr, "IPv4 database included: %s\n", dbipv4addr_registry_status);
-#else
-	fprintf(stderr, "IPv4 database not included\n");
-#endif
-
-#ifdef SUPPORT_DB_IPV6
-	fprintf(stderr, "IPv6 database included: %s\n", dbipv6addr_registry_status);
-#else
-	fprintf(stderr, "IPv6 database not included\n");
-#endif
-
-	fprintf(stderr, "\n");
-
-#ifdef SUPPORT_GEOIP
-#ifdef SUPPORT_GEOIP_V6
-#if defined (SUPPORT_GEOIP_COUNTRY_CODE_BY_ADDR_V6) && defined (SUPPORT_GEOIP_COUNTRY_NAME_BY_ADDR_V6)
-	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 & IPv6 support\n");
-#else
-	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 & IPv6 support (in compatibility mode)\n");
-#endif
-#else
-	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 support only\n");
-#endif
-#ifdef SUPPORT_GEOIP_LIB_VERSION
-	fprintf(stderr, "GeoIP dynamic library version (on this system): %s\n", GeoIP_lib_version());
-#else
-	fprintf(stderr, "GeoIP dynamic library version (on this system): compiled without detection\n");
-#endif
-	if (file_geoip_ipv4 != NULL && strlen(file_geoip_ipv4) > 0) {
-		fprintf(stderr, "GeoIP IPv4 default file: %s\n", file_geoip_ipv4);
-	} else {
-		fprintf(stderr, "GeoIP IPv4 default file: not configured\n");
-	};
-#ifdef SUPPORT_GEOIP_V6
-	if (file_geoip_ipv6 != NULL && strlen(file_geoip_ipv6) > 0) {
-		fprintf(stderr, "GeoIP IPv6 default file: %s\n", file_geoip_ipv6);
-	} else {
-		fprintf(stderr, "GeoIP IPv6 default file: not configured\n");
-	};
-#endif
-#else
-	fprintf(stderr, "GeoIP support not enabled\n");
-#endif
-
-	fprintf(stderr, "\n");
-
-#ifdef SUPPORT_IP2LOCATION
-	fprintf(stderr, "IP2Location support enabled, compiled with API version: %s\n", xmakestr(API_VERSION));
-	if (file_ip2location_ipv4 != NULL && strlen(file_ip2location_ipv4) > 0) {
-		fprintf(stderr, "IP2Location IPv4 default file: %s\n", file_ip2location_ipv4);
-	} else {
-		fprintf(stderr, "IP2Location IPv4 default file: not configured\n");
-	};
-	if (file_ip2location_ipv6 != NULL && strlen(file_ip2location_ipv6) > 0) {
-		fprintf(stderr, "IP2Location IPv6 default file: %s\n", file_ip2location_ipv6);
-	} else {
-		fprintf(stderr, "IP2Location IPv6 default file: not configured\n");
-	};
-#else
-	fprintf(stderr, "IP2Location support not enabled\n");
-#endif
-
-};
-
-void printcopyright(void) {
-	fprintf(stderr, "%s\n", PROGRAM_COPYRIGHT);
-};
-
-void printinfo(void)  {
-	printversion();
-	printcopyright();
-	fprintf(stderr, "This program formats and calculates IPv6 addresses and can do many more tricky things\n");
-	fprintf(stderr, "See '%s -?|-h|--help or -v -v' for more details\n\n", PROGRAM_NAME);
-};
+/* features */
+int feature_zeroize = 1; // always supported
+int feature_anon    = 1; // always supported
+int feature_kp      = 0; // will be checked later
 
 
 /**************************************************/
@@ -225,7 +92,7 @@ int main(int argc, char *argv[]) {
 	char resultstring2[NI_MAXHOST] = "";
 	char resultstring3[NI_MAXHOST] = "";
 	int retval = 1, i, j, lop, result;
-	unsigned long int command = 0;
+	uint32_t command = 0;
 	int bit_start = 0, bit_end = 0, force_prefix = 0;
 	char *input1 = NULL, *input2 = NULL;
 	int inputc;
@@ -251,7 +118,7 @@ int main(int argc, char *argv[]) {
 
 	/* IID statistics */
 	s_iid_statistics iid_statistics;
-	int iid_privacy_result;
+	int iid_random_result;
 
 	/* clear address structures */
 	ipv6addr_clearall(&ipv6addr);
@@ -269,27 +136,72 @@ int main(int argc, char *argv[]) {
 	int linecounter = 0;
 	int flush_mode = 0;
 
+	/* options */
+	struct option longopts[MAXLONGOPTIONS];
+	char   shortopts[NI_MAXHOST] = "";
+	int    longopts_maxentries = 0;
+
+	/* initialize debug value from environment for bootstrap debugging */
+	ipv6calc_debug_from_env();
+
+	/* add options */
+	ipv6calc_options_add_common_anon(shortopts, sizeof(shortopts), longopts, &longopts_maxentries);
+	ipv6calc_options_add_common_basic(shortopts, sizeof(shortopts), longopts, &longopts_maxentries);
+	ipv6calc_options_add(shortopts, sizeof(shortopts), longopts, &longopts_maxentries, ipv6calc_shortopts, ipv6calc_longopts, MAXENTRIES_ARRAY(ipv6calc_longopts));
+
 	/* default */
-	result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, "anonymize-standard");
+	result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, ANONPRESET_DEFAULT);
 	if (result != 0) {
-		fprintf(stderr, "major problem, ipv6calc anonymization default preset not found: anonymize-standard\n");
+		fprintf(stderr, "major problem, ipv6calc anonymization default preset not found: %s", ANONPRESET_DEFAULT);
 		exit(EXIT_FAILURE);
 	};
 
 	if (argc <= 1) {
-		printinfo();
+		ipv6calc_printinfo();
 		exit(EXIT_FAILURE);
 	};
 
 	/* Fetch the command-line arguments. */
-	while ((i = getopt_long(argc, argv, ipv6calc_shortopts, ipv6calc_longopts, &lop)) != EOF) {
+	if (ipv6calc_debug != 0) {
+		fprintf(stderr, "%s/%s: Start parsing options: shortopts=%s\n", __FILE__, __func__, shortopts);
+
+		i = 0;
+		while(longopts[i].name != NULL) {
+			fprintf(stderr, "%s/%s: Long option: %s/%d/%08x\n", __FILE__, __func__, longopts[i].name, longopts[i].has_arg, longopts[i].val);
+			i++;
+		};
+	};
+	
+	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
+		if (ipv6calc_debug != 0) {
+			fprintf(stderr, "%s/%s: Parsing option: 0x%08x\n", __FILE__, __func__, i);
+		};
+
+		/* catch "common basic" options */
+		result = ipv6calcoptions_common_basic(i, optarg, longopts);
+		if (result == 0) {
+			// found
+			continue;
+		};
+
+		/* catch "common anon" options */
+		result = ipv6calcoptions_common_anon(i, optarg, longopts, &ipv6calc_anon_set);
+		if (result == 0) {
+			// found
+			continue;
+		};
+
+		/* specific options */
 		switch (i) {
 			case -1:
 				break;
 
 			case 'v':
-				if ((command & CMD_printversion) != 0) {
-					// second time '-v'
+				if ((command & CMD_printversion_verbose) != 0) {
+					// 3rd time '-v'
+					command |= CMD_printversion_verbose2;
+				} else if ((command & CMD_printversion) != 0) {
+					// 2nd time '-v'
 					command |= CMD_printversion_verbose;
 				} else {
 					command |= CMD_printversion;
@@ -303,149 +215,33 @@ int main(int argc, char *argv[]) {
 			case 'h':
 			case '?':
 				command |= CMD_printhelp;
-				fprintf(stderr, "%s: help option detected\n", DEBUG_function_name);
+				if (ipv6calc_debug != 0) {
+					fprintf(stderr, "%s: help option detected\n", DEBUG_function_name);
+				};
 				break;
 				
-			case 'd':
-				if ((strlen(optarg) > 2) && ((strncmp(optarg, "0x", 2) == 0) || (strncmp(optarg, "0X", 2)) == 0)) {
-					// convert hex
-					if (sscanf(optarg + 2, "%lx", &ipv6calc_debug) == 0) {
-						ipv6calc_debug = 0;
-						fprintf(stderr, "%s: can't parse value for debug option: %s\n", DEBUG_function_name, optarg);
-						exit (1);
-					} else {
-					};
-				} else {
-					ipv6calc_debug = atol(optarg);
-				};
-
-				fprintf(stderr, "%s: given debug value: %lx\n", DEBUG_function_name, ipv6calc_debug);
-				break;
-
-			case DB_ip2location_ipv4:
-#ifdef SUPPORT_IP2LOCATION
-				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "%s: Got IP2Location IPv4 database file: %s\n", DEBUG_function_name, optarg);
-				};
-				snprintf(file_ip2location_ipv4, sizeof(file_ip2location_ipv4) - 1, "%s", optarg);
-				use_ip2location_ipv4 = 1;
-#else
-				if ((formatoptions & FORMATOPTION_quiet) == 0) {
-					fprintf(stderr, " Support for option '--db-ip2location-ipv4 <IP2Location IPv4 database file>' not compiled in, IP2Location support disabled\n");
-				};
-#endif
-				break;
-
-			case DB_ip2location_ipv6:
-#ifdef SUPPORT_IP2LOCATION
-				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "%s: Got IP2Location IPv6 database file: %s\n", DEBUG_function_name, optarg);
-				};
-				snprintf(file_ip2location_ipv6, sizeof(file_ip2location_ipv6) - 1, "%s", optarg);
-				use_ip2location_ipv6 = 1;
-#else
-				if ((formatoptions & FORMATOPTION_quiet) == 0) {
-					fprintf(stderr, " Support for option '--db-ip2location-ipv6 <IP2Location IPv6 database file>' not compiled in, IP2Location support disabled\n");
-				};
-#endif
-				break;
-
 			case 'L':
-#ifdef IP2LOCATION_DEFAULT_FILE_IPV4
-				use_ip2location_ipv4 = 1;
-#endif
-#ifdef IP2LOCATION_DEFAULT_FILE_IPV6
-				use_ip2location_ipv6 = 1;
-#endif
-				if (use_ip2location_ipv4 == 0 && use_ip2location_ipv6 == 0) {
-					if ((formatoptions & FORMATOPTION_quiet) == 0) {
-						fprintf(stderr, " Neither support for IP2Location IPv4 or IPv6 default database is compiled in, IP2Location support disabled\n");
-					};
-				};
+				fprintf(stderr, "Option is obsolete: -L\n");
 				break;
 
 			case DB_ip2location_ipv4_default:
-#ifdef IP2LOCATION_DEFAULT_FILE_IPV4
-				use_ip2location_ipv4 = 1;
-#else
-				if ((formatoptions & FORMATOPTION_quiet) == 0) {
-					fprintf(stderr, " Support for option '--db-ip2location-ipv4-default' not compiled in, IP2Location IPv4 support disabled\n");
-				};
-#endif
+				fprintf(stderr, "Option is obsolete: --db-ip2location-ipv4-default\n");
 				break;
 
 			case DB_ip2location_ipv6_default:
-#ifdef IP2LOCATION_DEFAULT_FILE_IPV6
-				use_ip2location_ipv6 = 1;
-#else
-				if ((formatoptions & FORMATOPTION_quiet) == 0) {
-					fprintf(stderr, " Support for option '--db-ip2location-ipv6-default' not compiled in, IP2Location IPv6 support disabled\n");
-				};
-#endif
-				break;
-
-			case DB_geoip_ipv4:
-#ifdef SUPPORT_GEOIP
-				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "%s: Got GeoIP IPv4 database file: %s\n", DEBUG_function_name, optarg);
-				};
-				snprintf(file_geoip_ipv4, sizeof(file_geoip_ipv4) - 1, "%s", optarg);
-				use_geoip_ipv4 = 1;
-#else
-				if ((formatoptions & FORMATOPTION_quiet) == 0) {
-					fprintf(stderr, " Support for option '--db-geoip-ipv4 <GeoIP IPv4 database file>' not compiled in, GeoIP support disabled\n");
-				};
-#endif
-				break;
-
-			case DB_geoip_ipv6:
-#ifdef SUPPORT_GEOIP_V6
-				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "%s: Got GeoIP IPv6 database file: %s\n", DEBUG_function_name, optarg);
-				};
-				snprintf(file_geoip_ipv6, sizeof(file_geoip_ipv6) - 1, "%s", optarg);
-				use_geoip_ipv6 = 1;
-#else
-				if ((formatoptions & FORMATOPTION_quiet) == 0) {
-					fprintf(stderr, " Support for option '--db-geo-ipv6 <GeoIP IPv6 database file>' not compiled in, GeoIP(v6) support disabled\n");
-				};
-#endif
+				fprintf(stderr, "Option is obsolete: --db-ip2location-ipv6-default\n");
 				break;
 
 			case 'G':
-#ifdef GEOIP_DEFAULT_FILE_IPV4
-				use_geoip_ipv4 = 1;
-#endif
-#ifdef GEOIP_DEFAULT_FILE_IPV6
-				use_geoip_ipv6 = 1;
-#endif
-				if (use_geoip_ipv4 == 0 && use_geoip_ipv6 == 0) {
-					if ((formatoptions & FORMATOPTION_quiet) == 0) {
-						fprintf(stderr, " Neither support for GeoIP IPv4 or IPv6 default database is compiled in, GeoIP support disabled\n");
-					};
-				};
+				fprintf(stderr, "Option is obsolete: -G\n");
 				break;
 
 			case DB_geoip_ipv4_default:
-#ifdef GEOIP_DEFAULT_FILE_IPV4
-				use_geoip_ipv4 = 1;
-#else
-				if ((formatoptions & FORMATOPTION_quiet) == 0) {
-					fprintf(stderr, " Support for option '--db-geoip-ipv4-default' not compiled in, GeoIP IPv4 support disabled\n");
-				};
-#endif
+				fprintf(stderr, "Option is obsolete: --db-geoip-ipv4-default\n");
 				break;
 
 			case DB_geoip_ipv6_default:
-#ifdef GEOIP_DEFAULT_FILE_IPV6
-#ifdef SUPPORT_GEOIP_V6
-				use_geoip_ipv6 = 1;
-#endif
-#else
-				if ((formatoptions & FORMATOPTION_quiet) == 0) {
-					fprintf(stderr, " Support for option '--db-geoip-ipv6-default' not compiled in, GeoIP IPv6 support disabled\n");
-				};
-#endif
+				fprintf(stderr, "Option is obsolete: --db-geoip-ipv6-default\n");
 				break;
 
 			case CMD_printexamples:
@@ -556,94 +352,6 @@ int main(int argc, char *argv[]) {
 				command = CMD_showinfotypes;
 				break;
 
-			case CMD_ANON_MASK_IID:
-				mask_iid = 1;
-				mask_iid = atoi(optarg);
-				if (mask_iid < 0 || mask_iid > 64) {
-					fprintf(stderr, " value for option 'mask-iid' out-of-range  [0-64]\n");
-					exit(EXIT_FAILURE);
-				};
-				ipv6calc_anon_set.mask_iid = mask_iid;
-				snprintf(ipv6calc_anon_set.name, sizeof(ipv6calc_anon_set.name) - 1, "%s", "custom");
-				break;
-
-			case CMD_ANON_MASK_IPV4:
-				mask_ipv4 = atoi(optarg);
-				if (mask_ipv4 < 0 || mask_ipv4 > 32) {
-					fprintf(stderr, " value for option 'mask-ipv4' out-of-range  [0-32]\n");
-					exit(EXIT_FAILURE);
-				};
-				ipv6calc_anon_set.mask_ipv4 = mask_ipv4;
-				snprintf(ipv6calc_anon_set.name, sizeof(ipv6calc_anon_set.name) - 1, "%s", "custom");
-				break;
-
-			case CMD_ANON_MASK_IPV6:
-				mask_ipv6 = atoi(optarg);
-				if (mask_ipv6 < 0 || mask_ipv6 > 64) {
-					fprintf(stderr, " value for option 'mask-ipv6' out-of-range  [0-64]\n");
-					exit(EXIT_FAILURE);
-				};
-				ipv6calc_anon_set.mask_ipv6 = mask_ipv6;
-				snprintf(ipv6calc_anon_set.name, sizeof(ipv6calc_anon_set.name) - 1, "%s", "custom");
-				break;
-
-			case CMD_ANON_MASK_MAC:
-				mask_mac = atoi(optarg);
-				if (mask_mac < 0 || mask_mac > 48) {
-					fprintf(stderr, " value for option 'mask-mac' out-of-range  [0-48]\n");
-					exit(EXIT_FAILURE);
-				};
-				ipv6calc_anon_set.mask_mac = mask_mac;
-				snprintf(ipv6calc_anon_set.name, sizeof(ipv6calc_anon_set.name) - 1, "%s", "custom");
-				break;
-
-			case CMD_ANON_PRESET_STANDARD:
-				result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, "as");
-				if (result != 0) {
-					fprintf(stderr, "ipv6calc anonymization preset not found: anonymize-standard\n");
-					exit(EXIT_FAILURE);
-				};
-				break;
-
-			case CMD_ANON_PRESET_CAREFUL:
-				result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, "ac");
-				if (result != 0) {
-					fprintf(stderr, "ipv6calc anonymization preset not found: anonymize-careful\n");
-					exit(EXIT_FAILURE);
-				};
-				break;
-
-			case CMD_ANON_PRESET_PARANOID:
-				result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, "ap");
-				if (result != 0) {
-					fprintf(stderr, "ipv6calc anonymization preset not found: anonymize-paranoid\n");
-					exit(EXIT_FAILURE);
-				};
-				break;
-
-			case CMD_ANON_PRESET_OPTION:
-				result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, optarg);
-				if (result != 0) {
-					fprintf(stderr, "ipv6calc anonymization preset not found: %s\n", optarg);
-					exit(EXIT_FAILURE);
-				};
-				break;
-
-			case CMD_ANON_METHOD_OPTION:
-				for (i = 0; i < sizeof(ipv6calc_anon_methods) / sizeof(s_ipv6calc_anon_methods); i++) {
-					if (strcmp(ipv6calc_anon_methods[i].name, optarg) == 0) {
-						ipv6calc_anon_set.method = ipv6calc_anon_methods[i].method;
-						snprintf(ipv6calc_anon_set.name, sizeof(ipv6calc_anon_set.name) -1, "%s", "custom");
-						break;
-					};
-				};
-
-				if (i == sizeof(ipv6calc_anon_methods) / sizeof(s_ipv6calc_anon_methods)) {
-					fprintf(stderr, "ipv6calc anonymization method not supported: %s\n", optarg);
-					exit(EXIT_FAILURE);
-				};
-				break;
-
 			case CMD_6rd_relay_prefix:
 				retval = addr_to_ipv4addrstruct(optarg, resultstring, &ipv4addr2);
 				break;
@@ -732,7 +440,6 @@ int main(int argc, char *argv[]) {
 				formatoptions |= FORMATOPTION_machinereadable;
 				break;
 				
-			case 'q':	
 			case FORMATOPTION_NUM_quiet + FORMATOPTION_NUM_HEAD:
 				formatoptions |= FORMATOPTION_quiet;
 				break;
@@ -788,9 +495,8 @@ int main(int argc, char *argv[]) {
 
 			case 'A':	
 			case CMD_actiontype:
-				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "%s: Got action string: %s\n", DEBUG_function_name, optarg);
-				};
+				DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Got action string: %s", optarg);
+
 				if ((strcmp(optarg, "-?") == 0) || (strcmp(optarg, "-h") == 0) || (strcmp(optarg, "--help") == 0) ) {
 					action = ACTION_auto;
 					command = CMD_printhelp;
@@ -805,9 +511,7 @@ int main(int argc, char *argv[]) {
 				break;
 
 			case 'E':	
-				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "%s: Got expression string: %s\n", DEBUG_function_name, optarg);
-				};
+				DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Got expression string: %s", optarg);
 
 				if ((strcmp(optarg, "-?") == 0) || (strcmp(optarg, "-h") == 0) || (strcmp(optarg, "--help") == 0) ) {
 					action = ACTION_filter;
@@ -820,21 +524,43 @@ int main(int argc, char *argv[]) {
 				if (result != 0) {
 					exit(EXIT_FAILURE);
 				};
+
+				if (action == ACTION_undefined) {
+					// autodefine action
+					action = ACTION_filter;
+					action_given = 1;
+				};
 				break;
 				
 			default:
 				fprintf(stderr, "Usage: (see '%s --command -?|-h|--help' for more help)\n", PROGRAM_NAME);
-				printhelp();
+				ipv6calc_printhelp();
 				exit(EXIT_FAILURE);
 		};
 	};
 	argv += optind;
 	argc -= optind;
 
+	if (ipv6calc_quiet != 0) {
+		formatoptions |= FORMATOPTION_quiet;
+	};
+
+	/* initialise database wrapper */
+	result = libipv6calc_db_wrapper_init();
+	if (result != 0) {
+		exit(EXIT_FAILURE);
+	};
+
+	/* check for KeepTypeAsnCC support */
+	if ((libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEASNCC_IPV4_REQ_DB) == 1) \
+	    && (libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEASNCC_IPV6_REQ_DB) == 1)) {
+		feature_kp = 1;
+	};
+
 	/* print help handling */
 	if (command == CMD_printhelp) {
 		if ( (outputtype == FORMAT_undefined) && (inputtype == FORMAT_undefined) && (action == ACTION_undefined)) {
-			printhelp();
+			ipv6calc_printhelp();
 			exit(EXIT_FAILURE);
 		} else if (outputtype == FORMAT_auto) {
 			if (inputtype == FORMAT_undefined) {
@@ -846,7 +572,7 @@ int main(int argc, char *argv[]) {
 			printhelp_inputtypes(formatoptions);
 			exit(EXIT_FAILURE);
 		} else if (action == ACTION_auto) {
-			printhelp_actiontypes(formatoptions);
+			printhelp_actiontypes(formatoptions, ipv6calc_longopts);
 			exit(EXIT_FAILURE);
 		} else if (action != ACTION_undefined) {
 			printhelp_action_dispatcher(action, 0);
@@ -861,44 +587,44 @@ int main(int argc, char *argv[]) {
 		exit(EXIT_FAILURE);
 	};
 
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "Debug value:%08lx command:%08lx inputtype:%08lx outputtype:%08lx action:%08lx formatoptions:%08lx\n", (unsigned long) ipv6calc_debug, command, (unsigned long) inputtype, (unsigned long) outputtype, (unsigned long) action, (unsigned long) formatoptions); 
-	};
-	
+	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Debug value:%08lx command:%08lx inputtype:%08lx outputtype:%08lx action:%08lx formatoptions:%08lx", (unsigned long) ipv6calc_debug, (unsigned long) command, (unsigned long) inputtype, (unsigned long) outputtype, (unsigned long) action, (unsigned long) formatoptions);
+
 	/* do work depending on selection */
 	if ((command & CMD_printversion) != 0) {
 		if ((command & CMD_printversion_verbose) != 0) {
-			printversion_verbose();
+			printversion_verbose(((command & CMD_printversion_verbose2) !=0) ? LEVEL_VERBOSE2 : LEVEL_VERBOSE);
 		} else {
 			printversion();
 		};
 		exit(EXIT_SUCCESS);
 	};
 
+	if (action == ACTION_anonymize) {
+		/* check requirements */
+		if (libipv6calc_anon_supported(&ipv6calc_anon_set) == 0) {
+			fprintf(stderr, "ipv6calc anonymization method not supported: %s\n", libipv6calc_anon_method_name(&ipv6calc_anon_set));
+			exit(EXIT_FAILURE);
+		};
+	};
+
 	if (command == CMD_printoldoptions) {
-		printhelp_oldoptions();
+		printhelp_oldoptions(longopts);
 		exit(EXIT_FAILURE);
 	};
 	
 	if (argc > 0) {
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "%s: Got input %s\n", DEBUG_function_name, argv[0]);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Got input %s", argv[0]);
 	} else {
 		if (isatty (STDIN_FILENO)) {
 		} else {
 			input_is_pipe = 1;
-			if (ipv6calc_debug != 0) {
-				fprintf(stderr, "%s: Input is a pipe\n", DEBUG_function_name);
-			};
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Input is a pipe");
 			formatoptions |= FORMATOPTION_quiet; // force quiet mode
 		};
 	};
 
 	/***** input type handling *****/
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Start of input type handling\n", DEBUG_function_name);
-	};
+	DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of input type handling");
 
 	/* check length of input */
 	if (argc > 0) {
@@ -931,14 +657,10 @@ PIPE_input:
 		linecounter++;
 
 		if (linecounter == 1) {
-			if (ipv6calc_debug == 1) {
-				fprintf(stderr, "Ok, proceeding stdin...\n");
-			};
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Ok, proceeding stdin...\n");
 		};
 		
-		if (ipv6calc_debug == 1) {
-			fprintf(stderr, "Line: %d\r", linecounter);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Line: %d", linecounter);
 
 		if (strlen(linebuffer) >= NI_MAXHOST) {
 			fprintf(stderr, "Line too long: %d\n", linecounter);
@@ -955,9 +677,7 @@ PIPE_input:
 			linebuffer[strlen(linebuffer) - 1] = '\0';
 		};
 		
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "%s: stdin got line: '%s'\n", DEBUG_function_name, linebuffer);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "stdin got line: '%s'", linebuffer);
 
 		if (linebuffer[strlen(linebuffer) - 1] == '\n') {
 			/* remove trailing \n */
@@ -982,18 +702,14 @@ PIPE_input:
 		input1 = token;
 		inputc = 1;
 
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "%s: Token 1: '%s'\n", DEBUG_function_name, input1);
-		};
+		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Token 1: '%s'", input1);
 
 		/* check for second token */
 		if (*ptrptr[0] != '\0') {
 			input2 = *ptrptr;
 			inputc = 2;
 
-			if (ipv6calc_debug != 0) {
-				fprintf(stderr, "%s: Token 2: '%s'\n", DEBUG_function_name, input2);
-			};
+			DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Token 2: '%s'", input2);
 		};
 
 	} else {
@@ -1007,15 +723,14 @@ PIPE_input:
 	};
 	
 	/* reset input type in case of action=filter and pipe mode */
-	if (input_is_pipe == 1 && action_given == 1 && action == ACTION_filter) {
-		inputtype = 0;
+	if ((input_is_pipe == 1) && (action_given == 1) && (action == ACTION_filter)) {
+		DEBUGPRINT_NA(DEBUG_ipv6calc_general, "reset input type for later autodetection");
+		inputtype = FORMAT_auto;
 	};
 
 	/* autodetection */
 	if ((inputtype == FORMAT_undefined || inputtype == FORMAT_auto) && inputc > 0) {
-		if (ipv6calc_debug != 0) {
-			fprintf(stderr, "%s: Call input type autodetection\n", DEBUG_function_name);
-		};
+		DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Call input type autodetection");
 		/* no input type specified or automatic selected */
 		if ((formatoptions & FORMATOPTION_quiet) == 0) {
 			fprintf(stderr, "No input type specified, try autodetection...");
@@ -1035,6 +750,8 @@ PIPE_input:
 		} else {
 			fprintf(stderr, "no result!\n");
 		};
+	} else {
+		DEBUGPRINT_NA(DEBUG_ipv6calc_general, "input type autodetection skipped");
 	};
 
 	/* auto set of output type*/
@@ -1075,9 +792,7 @@ PIPE_input:
 	};
 
 	/* check formatoptions for validity */
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: check format option of output type: 0x%08lx\n", DEBUG_function_name, (unsigned long) outputtype);
-	};
+	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "check format option of output type: 0x%08lx", (unsigned long) outputtype);
 		
 	for (i = 0; i < (int) (sizeof(ipv6calc_outputformatoptionmap) / sizeof(ipv6calc_outputformatoptionmap[0])); i++) {
 		if (outputtype != ipv6calc_outputformatoptionmap[i][0]) {
@@ -1111,9 +826,7 @@ PIPE_input:
 	/* proceed input depending on type */	
 	retval = -1; /* default */
 
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Process input (inputtype: 0x%08lx, count=%d)\n", DEBUG_function_name, (unsigned long) inputtype, inputc);
-	};
+	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Process input (inputtype: 0x%08lx, count=%d)", (unsigned long) inputtype, inputc);
 
 	switch (inputtype) {
 		case FORMAT_ipv6addr:
@@ -1249,15 +962,11 @@ PIPE_input:
 		exit(EXIT_FAILURE);
 	};
 	
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: End of input type handling\n", DEBUG_function_name);
-	};
+	DEBUGPRINT_NA(DEBUG_ipv6calc_general, "End of input type handling");
 
 	/***** postprocessing input *****/
 	
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Start of postprocessing input\n", DEBUG_function_name);
-	};
+	DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of postprocessing input");
 
 	if (ipv6addr.flag_valid == 1) {
 		/* force prefix */
@@ -1282,9 +991,7 @@ PIPE_input:
 		
 		/* start bit */
 		if ((formatoptions & FORMATOPTION_printstart) != 0) {
-			if (ipv6calc_debug != 0) {
-				fprintf(stderr, "%s: Set bit start to: %d\n", DEBUG_function_name, bit_start);
-			};
+			DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Set bit start to: %d", bit_start);
 			ipv6addr.bit_start = (uint8_t) bit_start;
 			ipv6addr.flag_startend_use = 1;
 		} else {
@@ -1293,9 +1000,7 @@ PIPE_input:
 		
 		/* end bit */
 		if ((formatoptions & FORMATOPTION_printend) != 0) {
-			if (ipv6calc_debug != 0) {
-				fprintf(stderr, "%s: Set bit end to: %d\n", DEBUG_function_name, bit_end);
-			};
+			DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Set bit end to: %d", bit_end);
 			ipv6addr.bit_end = (uint8_t) bit_end;
 			ipv6addr.flag_startend_use = 1;
 		} else {
@@ -1360,23 +1065,17 @@ PIPE_input:
 	};
 
 	
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: result of 'inputtype': %d\n", DEBUG_function_name, retval);
-	};
+	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "result of 'inputtype': %d", retval);
 
 	if (retval != 0) {
 		fprintf(stderr, "%s\n", resultstring);
 		exit(EXIT_FAILURE);
 	};
 	
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: End of postprocessing input\n", DEBUG_function_name);
-	};
+	DEBUGPRINT_NA(DEBUG_ipv6calc_general, "End of postprocessing input");
 	
 	/***** action *****/
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Start of action\n", DEBUG_function_name);
-	};
+	DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of action");
 
 	/***** automatic output handling *****/
 	if ( outputtype == FORMAT_undefined ) {
@@ -1431,9 +1130,7 @@ PIPE_input:
 	/* clear resultstring */
 	snprintf(resultstring, sizeof(resultstring) - 1, "%s", "");
 
-	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Process action (action: 0x%08lx)\n", DEBUG_function_name, (unsigned long) action);
-	};
+	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Process action (action: 0x%08lx)", (unsigned long) action);
 	
 	switch (action) {
 		case ACTION_mac_to_eui64:
@@ -1472,7 +1169,7 @@ PIPE_input:
 					fprintf(stderr, "No valid IPv4 address given!\n");
 					exit(EXIT_FAILURE);
 				};
-				libipv4addr_anonymize(&ipv4addr, ipv6calc_anon_set.mask_ipv4);
+				libipv4addr_anonymize(&ipv4addr, ipv6calc_anon_set.mask_ipv4, ipv6calc_anon_set.method);
 			} else if ((inputtype == FORMAT_ipv6addr || inputtype == FORMAT_bitstring || inputtype == FORMAT_revnibbles_int || inputtype == FORMAT_revnibbles_arpa || inputtype == FORMAT_base85 || inputtype == FORMAT_ipv6literal) && outputtype == FORMAT_ipv6addr) {
 				/* anonymize IPv6 address */
 				if (ipv6addr.flag_valid != 1) {
@@ -1486,7 +1183,14 @@ PIPE_input:
 					fprintf(stderr, "No valid MAC address given!\n");
 					exit(EXIT_FAILURE);
 				};
-				libmacaddr_anonymize(&macaddr, ipv6calc_anon_set.mask_mac);
+				libmacaddr_anonymize(&macaddr, &ipv6calc_anon_set);
+			} else if (inputtype == FORMAT_eui64 && outputtype == FORMAT_eui64) {
+				/* anonymize EUI-64 address */
+				if (eui64addr.flag_valid != 1) {
+					fprintf(stderr, "No valid EUI-64 address given!\n");
+					exit(EXIT_FAILURE);
+				};
+				libeui64_anonymize(&eui64addr, &ipv6calc_anon_set);
 			} else {
 				fprintf(stderr, "Unsupported anonymization!\n");
 				exit(EXIT_FAILURE);
@@ -1582,9 +1286,7 @@ PIPE_input:
 			break;
 
 		case ACTION_filter:
-			if (ipv6calc_debug != 0) {
-				fprintf(stderr, "%s: Start of action: filter\n", DEBUG_function_name);
-			};
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of action: filter");
 
 			outputtype = inputtype;
 
@@ -1605,9 +1307,7 @@ PIPE_input:
 
 			if (result != 0) {
 				/* skip everything */
-				if (ipv6calc_debug != 0) {
-					fprintf(stderr, "%s: filter result SKIP: '%s'\n", DEBUG_function_name, linebuffer);
-				};
+				DEBUGPRINT_WA(DEBUG_ipv6calc_general, "filter result SKIP: '%s'", linebuffer);
 			} else {
 				snprintf(resultstring, sizeof(resultstring) - 1, "%s", linebuffer);
 			};
@@ -1641,6 +1341,15 @@ PIPE_input:
 	
 	/* catch showinfo */	
 	if (command == CMD_showinfo) {
+		// change anonymization method depending on support
+		if (feature_kp == 1) {
+			result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, "keep-type-asn-cc");
+			if (result != 0) {
+				// fallback
+				result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, ANONPRESET_DEFAULT);
+			};
+		};
+
 		if (ipv6addr.flag_valid == 1) {
 			retval = showinfo_ipv6addr(&ipv6addr, formatoptions);
 	       	} else if (ipv4addr.flag_valid == 1) {
@@ -1740,10 +1449,11 @@ PIPE_input:
 			};
 
 			if ((formatoptions & FORMATOPTION_print_iid_var) == FORMATOPTION_print_iid_var) {
-				iid_privacy_result = ipv6addr_privacyextensiondetection(&ipv6addr, &iid_statistics);
-				sprintf(resultstring2, "%-40s R=%d h=%7.3f r=%7.3f db= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d da= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d dd= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d dda= %d", resultstring, \
-					iid_privacy_result, iid_statistics.hexdigit, iid_statistics.lls_residual, \
+				iid_random_result = ipv6addr_iidrandomdetection(&ipv6addr, &iid_statistics);
+				sprintf(resultstring2, "%-40s R=%d h=%7.3f r=%7.3f db= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d dbh= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d da= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d dd= %d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d dda= %d", resultstring, \
+					iid_random_result, iid_statistics.hexdigit, iid_statistics.lls_residual, \
 					iid_statistics.digit_blocks[0], iid_statistics.digit_blocks[1], iid_statistics.digit_blocks[2], iid_statistics.digit_blocks[3], iid_statistics.digit_blocks[4], iid_statistics.digit_blocks[5], iid_statistics.digit_blocks[6], iid_statistics.digit_blocks[7], iid_statistics.digit_blocks[8], iid_statistics.digit_blocks[9], iid_statistics.digit_blocks[10], iid_statistics.digit_blocks[11], iid_statistics.digit_blocks[12], iid_statistics.digit_blocks[13], iid_statistics.digit_blocks[14], iid_statistics.digit_blocks[15], \
+					iid_statistics.digit_blocks_hexdigit[0], iid_statistics.digit_blocks_hexdigit[1], iid_statistics.digit_blocks_hexdigit[2], iid_statistics.digit_blocks_hexdigit[3], iid_statistics.digit_blocks_hexdigit[4], iid_statistics.digit_blocks_hexdigit[5], iid_statistics.digit_blocks_hexdigit[6], iid_statistics.digit_blocks_hexdigit[7], iid_statistics.digit_blocks_hexdigit[8], iid_statistics.digit_blocks_hexdigit[9], iid_statistics.digit_blocks_hexdigit[10], iid_statistics.digit_blocks_hexdigit[11], iid_statistics.digit_blocks_hexdigit[12], iid_statistics.digit_blocks_hexdigit[13], iid_statistics.digit_blocks_hexdigit[14], iid_statistics.digit_blocks_hexdigit[15], \
 					iid_statistics.digit_amount[0], iid_statistics.digit_amount[1], iid_statistics.digit_amount[2], iid_statistics.digit_amount[3], iid_statistics.digit_amount[4], iid_statistics.digit_amount[5], iid_statistics.digit_amount[6], iid_statistics.digit_amount[7], iid_statistics.digit_amount[8], iid_statistics.digit_amount[9], iid_statistics.digit_amount[10], iid_statistics.digit_amount[11], iid_statistics.digit_amount[12], iid_statistics.digit_amount[13], iid_statistics.digit_amount[14], iid_statistics.digit_amount[15], \
 					iid_statistics.digit_delta[0], iid_statistics.digit_delta[1], iid_statistics.digit_delta[2], iid_statistics.digit_delta[3], iid_statistics.digit_delta[4], iid_statistics.digit_delta[5], iid_statistics.digit_delta[6], iid_statistics.digit_delta[7], iid_statistics.digit_delta[8], iid_statistics.digit_delta[9], iid_statistics.digit_delta[10], iid_statistics.digit_delta[11], iid_statistics.digit_delta[12], iid_statistics.digit_delta[13], iid_statistics.digit_delta[14], iid_statistics.digit_delta[15], \
 					iid_statistics.digit_delta[16], iid_statistics.digit_delta[17], iid_statistics.digit_delta[18], iid_statistics.digit_delta[19], iid_statistics.digit_delta[20], iid_statistics.digit_delta[21], iid_statistics.digit_delta[22], iid_statistics.digit_delta[23], iid_statistics.digit_delta[24], iid_statistics.digit_delta[25], iid_statistics.digit_delta[26], iid_statistics.digit_delta[27], iid_statistics.digit_delta[28], iid_statistics.digit_delta[29], iid_statistics.digit_delta[30], \
@@ -1771,12 +1481,18 @@ PIPE_input:
 			break;
 			
 		case FORMAT_eui64:
-			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_eui64\n", DEBUG_function_name); }
-			if (action != ACTION_mac_to_eui64) { fprintf(stderr, "Specify proper action or input for output format: eui64\n"); exit(EXIT_FAILURE); };
-			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid EUI-64 identifier given!\n"); exit(EXIT_FAILURE); };
-			if (ipv6addr.prefixlength != 64) { fprintf(stderr, "No valid EUI-64 identifier given!\n"); exit(EXIT_FAILURE); };
-			formatoptions |= FORMATOPTION_printsuffix;
-			retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, formatoptions);
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_eui64");
+
+			if (action == ACTION_mac_to_eui64) {
+				if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid EUI-64 identifier given!\n"); exit(EXIT_FAILURE); };
+				if (ipv6addr.prefixlength != 64) { fprintf(stderr, "No valid EUI-64 identifier given!\n"); exit(EXIT_FAILURE); };
+				formatoptions |= FORMATOPTION_printsuffix;
+				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, formatoptions);
+			} else if (action == ACTION_anonymize) {
+				retval = libeui64_eui64addrstruct_to_string(&eui64addr, resultstring, formatoptions);
+			} else {
+				fprintf(stderr, "Specify proper action or input for output format: eui64\n"); exit(EXIT_FAILURE);
+			};
 			break;
 			
 		case FORMAT_mac:
