@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : showinfo.h
- * Version    : $Id: showinfo.h,v 1.17 2013/04/09 20:09:33 ds6peter Exp $
- * Copyright  : 2001-2012 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: showinfo.h,v 1.20 2013/10/18 06:23:42 ds6peter Exp $
+ * Copyright  : 2001-2013 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for showinfo.c
@@ -13,7 +13,7 @@
 #include "libipv4addr.h"
 #include "libmac.h"
 
-#define DEBUG_showinfo		0x2
+#define DEBUG_showinfo		0x00000002l
 
 /* output version of machine readable format */
 // 1: never defined, until 0.51
@@ -25,12 +25,20 @@
 //	+ IP2LOCATION_DATABASE_INFO_IPV6 
 // 5: 0.92.0 to < 0.94.0
 //	+ IPV6CALC_FEATURES (see ipv6calc -v)
-// 6: 0.94.0 to current
+// 6: 0.94.0 to < 0.95.0
 //      TYPE renamed to IPV6_TYPE for alignment
 //      + IPV6_ANON
 //      + IPV4_ANON
 //      + SETTINGS_ANON
-#define IPV6CALC_OUTPUT_VERSION	6
+// 7: 0.95.0 to current
+//      - GEOIP_DATABASE_INFO_IPV4
+//      - GEOIP_DATABASE_INFO_IPV6
+//      + GEOIP_DATABASE_INFO
+//      - IP2LOCATION_DATABASE_INFO_IPV4
+//      - IP2LOCATION_INFO_IPV6
+//      + IP2LOCATION_DATABASE_INFO
+
+#define IPV6CALC_OUTPUT_VERSION	7
 
 /* prototypes */
 extern int  showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp, const uint32_t formatoptions);
