@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : test_ipv6calc.sh
-# Version    : $Id: test_ipv6calc.sh,v 1.41 2013/05/10 05:51:04 ds6peter Exp $
+# Version    : $Id: test_ipv6calc.sh,v 1.44 2013/11/02 16:41:01 ds6peter Exp $
 # Copyright  : 2001-2013 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc conversions
@@ -12,6 +12,14 @@ if [ ! -x ./ipv6calc ]; then
 	exit 1
 fi
 
+# Test proper option definitions
+echo "Test proper option definition"
+./ipv6calc -h >/dev/null
+if [ $? -ne 1 ]; then
+	echo "ERROR : something wrong in option definition"
+	exit 1
+fi
+
 # Test Scenarios for autodetection "good case"
 source ./test_scenarios.sh
 
@@ -148,8 +156,8 @@ NOPIPETEST--out eui64 00:0:F:6:4:5					=200:fff:fe06:405
 --action anonymize --mask-mac 40 01:23:45:67:89:a8			=01:23:45:67:89:00
 --action anonymize --mask-mac 8  ff:23:45:67:89:a8			=ff:00:00:00:00:00
 --action anonymize --mask-mac 7  ff:23:45:67:89:a8			=fe:00:00:00:00:00
---action anonymize --mask-mac 1  ff:23:45:67:89:a8			=80:00:00:00:00:00
--A anonymize --anonymize-preset zeroize-paranoid   2001:db8:2280:6901:224:21ff:fe01:2345  =2001:db8:2200::224:21ff:fe00:0
+--action anonymize --mask-mac 1  ff:23:45:67:89:a8			=82:00:00:00:00:00
+-A anonymize --anonymize-preset zeroize-paranoid   2001:db8:2280:6901:224:21ff:fe01:2345  =2001:db8:2200::
 -A anonymize --anonymize-preset zeroize-careful    2001:db8:2280:6901:224:21ff:fe01:2345  =2001:db8:2280::224:21ff:fe00:0
 -A anonymize --anonymize-preset zeroize-standard   2001:db8:2280:6901:224:21ff:fe01:2345  =2001:db8:2280:6900:224:21ff:fe00:0
 -A anonymize --anonymize-preset anonymize-paranoid 2001:db8:2280:6901:224:21ff:fe01:2345  =2001:db8:2209:a909:a969:4291:4022:4213
