@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : test_scenarios.sh
-# Version    : $Id: test_scenarios.sh,v 1.19 2013/04/13 08:10:56 ds6peter Exp $
+# Version    : $Id: test_scenarios.sh,v 1.37 2013/10/31 21:24:46 ds6peter Exp $
 # Copyright  : 2001-2013 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc (functions only)
@@ -60,33 +60,60 @@ fe80--218-8bff-fe17-a226s4.ipv6-literal.net					ipv6literal
 END
 }
 
-# Test Scenarios for reserved IPv4 addresses (RFC 5735)
+# Test Scenarios for reserved IPv4 addresses (RFC 5735) https://en.wikipedia.org/wiki/Reserved_IP_addresses
 testscenarios_ipv4_reserved() {
 	cat <<END | grep -v '^#'
 0.0.0.0			RFC1122#3.2.1.3
 0.255.255.255		RFC1122#3.2.1.3
+9.255.255.255		noRFC
 10.0.0.0		RFC1918#3
 10.255.255.255		RFC1918#3
+11.0.0.0		noRFC
+100.63.255.255		noRFC
+100.64.0.0		RFC6598
+100.127.255.255		RFC6598
+100.128.0.0		noRFC
+126.255.255.255		noRFC
 127.0.0.0		RFC1122#3.2.1.3
 127.255.255.255		RFC1122#3.2.1.3
+128.0.0.0		noRFC
+169.253.255.255		noRFC
 169.254.0.0		RFC3927#1
 169.254.255.255		RFC3927#1
+169.255.0.0		noRFC
+172.15.255.255		noRFC
 172.16.0.0		RFC1918#3
 172.31.255.255		RFC1918#3
+172.32.0.0		noRFC
+191.255.255.255		noRFC
 192.0.0.0		RFC5736#1
 192.0.0.255		RFC5736#1
+192.0.1.0		noRFC
+192.0.1.255		noRFC
 192.0.2.0		RFC5737#1
 192.0.2.255		RFC5737#1
+192.0.3.0		noRFC
+192.88.98.255		noRFC
 192.88.99.0		RFC3068#2.3
 192.88.99.255		RFC3068#2.3
+192.88.100.0		noRFC
+192.167.255.255		noRFC
 192.168.0.0		RFC1918#3
 192.168.255.255		RFC1918#3
+192.169.0.0		noRFC
+198.17.255.255		noRFC
 198.18.0.0		RFC2544#C.2.2
 198.19.255.255		RFC2544#C.2.2
+198.20.0.0		noRFC
+198.51.99.255		noRFC
 198.51.100.0		RFC5737#3
 198.51.100.255		RFC5737#3
+198.51.101.0		noRFC
+203.0.112.255		noRFC
 203.0.113.0		RFC5737#3
 203.0.113.255		RFC5737#3
+203.0.114.0		noRFC
+223.255.255.255		noRFC
 224.0.0.0		RFC3171#2
 239.255.255.255		RFC3171#2
 240.0.0.0		RFC1112#4
@@ -128,14 +155,15 @@ testscenarios_filter() {
 	cat <<END | grep -v '^#'
 3ffe:1a05:510:200:200:5efe:140.173.129.8	iid-isatap
 3ffe:831f:ce49:7601:8000:efff:af4a:86BF		teredo
-2001:db8:1:4135:7536:e4f:5513:4dd2		iid-privacy
+2001:db8:1:4135:7536:e4f:5513:4dd2		iid-random
 2001:db8:1:4135:208:54ff:fe00:1			iid-global
-2001:db8::a909:4291:c02d:5d1d			anonymized
+2001:db8::a909:4291:c02d:5d1d			anonymized-iid
 2001:db8::a909:4291:c02d:5d1d			iid-local
-2001:db8::a909:4291:4002:4217			anonymized
+2001:db8::a909:4291:4002:4217			anonymized-iid
 2001:db8::a909:4291:4002:4217			iid-eui48
-2001:db8::a909:4941:0:7				anonymized
-2001:db8::a909:4941:0:7				iid-privacy
+2001:db8::a909:4941:0:7				anonymized-iid
+2001:db8::a909:4941:0:7				iid-random
+2001:a69:a909:a909:a999:4941::1			anonymized-iid
 fe80::200:5efe:192.0.2.143			iid-isatap
 fe80::200:5efe:192.0.2.143			iid-global
 fe80::200:5efe:192.0.2.143			link-local
@@ -153,29 +181,38 @@ fe80::5e01:2345:6789				iid-isatap
 2001:1a:392e:a450:2cd3:75e1:6098:8104		orchid
 2001:1a:392e:a450:2cd3:75e1:6098:8104		^iid-local
 2001:1a:392e:a450:2cd3:75e1:6098:8104		^iid
-2001:1a:392e:a450:2cd3:75e1:6098:8104		^iid-privacy
+2001:1a:392e:a450:2cd3:75e1:6098:8104		^iid-random
 2001:19:a909:a909:a999:4843::e			orchid
-2001:19:a909:a909:a999:4843::e			anonymized
-2001:19:a909:a909:a999:4843::e			^iid-privacy
-3ffe:1a05:510:a909:a949:5214:48ca:d81d		anonymized
+2001:19:a909:a909:a999:4843::e			anonymized-iid
+2001:19:a909:a909:a999:4843::e			^iid-random
+3ffe:1a05:510:a909:a949:5214:48ca:d81d		anonymized-iid
 3ffe:1a05:510:a909:a949:5214:48ca:d81d		iid-isatap
-3ffe:1a05:510:a909:a949:5214:48ca:d81d		^iid-privacy
+3ffe:1a05:510:a909:a949:5214:48ca:d81d		^iid-random
+2001:4860:4801:2:3800:6006:1300:b075		^iid-random
 3ffe:ffff::a4ff:fe01:2345			iid-local
 3ffe:ffff::a4ff:fe01:2345			iid-eui48
-fe80:0000:0000:0000:0200:5efe:192.0.2.143	^anonymized 
-fe80:0000:0000:0000:0000:5e01:2345:6789		^anonymized 
-fe80:0000:0000:0000:0000:5eff:fe01:2345		^anonymized
-2001:0db8:0000:0000:81c0:0f3f:c807:1455		^anonymized
-3ffe:831f:ce49:7601:8000:efff:af4a:86BF		^anonymized
-2001:1a:392e:a450:2cd3:75e1:6098:8104		^anonymized
-3ffe:ffff::000:a4ff:fe01:2345			^anonymized
-2002:c0a8:f900:9:a929:4291:4021:132d		anonymized
+fe80:0000:0000:0000:0200:5efe:192.0.2.143	^anonymized-iid
+fe80:0000:0000:0000:0000:5e01:2345:6789		^anonymized-iid
+fe80:0000:0000:0000:0000:5eff:fe01:2345		^anonymized-iid
+2001:0db8:0000:0000:81c0:0f3f:c807:1455		^anonymized-iid
+3ffe:831f:ce49:7601:8000:efff:af4a:86BF		^anonymized-iid
+2001:1a:392e:a450:2cd3:75e1:6098:8104		^anonymized-iid
+3ffe:ffff::000:a4ff:fe01:2345			^anonymized-iid
+2002:c0a8:f900:9:a929:4291:4021:132d		anonymized-iid
 2002:c0a8:f900:9:a929:4291:4021:132d		6to4
-2001::d91f:cca0:3875:ffff:263c:ffff		anonymized
+2001::d91f:cca0:3875:ffff:263c:ffff		anonymized-iid
 2001::d91f:cca0:3875:ffff:263c:ffff		teredo
 2002:c000:0251::c000:0251			6to4-microsoft
 2002:c000:200:9:a929:4291:8c00:28		6to4-microsoft
-2002:c000:200:9:a929:4291:8c00:28		anonymized
+2002:c000:200:9:a929:4291:8c00:28		anonymized-iid
+a909:16fa:9092:23ff:a909:4941::7		anonymized-iid
+a909:16fa:9092:23ff:a909:4941::7		anonymized-prefix
+242.222.34.63					anonymized
+64:ff9b::f618:3b41				anonymized-iid
+2002:f618:3b41:0009:a929:4291:8f61:83b0		anonymized-iid
+2002:f618:3b41:0009:a929:4291:8f61:83b0		anonymized-prefix
+3ffe:831f:ce49:7601:8000:ffff:0a0b:f33a		anonymized-iid
+3ffe:831f:ce49:7601:8000:ffff:0a0b:f33a		^anonymized-prefix
 END
 }
 
@@ -188,17 +225,17 @@ testscenarios_genprivacyiid() {
 # Test scenarios for anonymization options (ipv6calc & ipv6loganon)
 testscenarios_anonymization_options() {
 	cat <<END | grep -v '^#'
---mask-iid  64 --anonymize-method zeroise	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef:123:4567
---mask-iid  60 --anonymize-method zeroise	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef:123:4560
---mask-iid  56 --anonymize-method zeroise	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef:123:4500
---mask-iid  48 --anonymize-method zeroise	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef:123:0
---mask-iid  40 --anonymize-method zeroise	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef:100:0
---mask-iid  36 --anonymize-method zeroise	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef::
---mask-iid  32 --anonymize-method zeroise	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef::
---mask-iid  28 --anonymize-method zeroise	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cde0::
---mask-iid  12 --anonymize-method zeroise	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89a0::
---mask-iid   8 --anonymize-method zeroise	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:8900::
---mask-iid   0 --anonymize-method zeroise	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500::
+--mask-eui64  64 --anonymize-method zeroize	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef:123:4567
+--mask-eui64  60 --anonymize-method zeroize	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef:123:4560
+--mask-eui64  56 --anonymize-method zeroize	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef:123:4500
+--mask-eui64  48 --anonymize-method zeroize	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef:123:0
+--mask-eui64  40 --anonymize-method zeroize	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef:100:0
+--mask-eui64  36 --anonymize-method zeroize	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef::
+--mask-eui64  32 --anonymize-method zeroize	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cdef::
+--mask-eui64  28 --anonymize-method zeroize	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89ab:cde0::
+--mask-eui64  12 --anonymize-method zeroize	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:89a0::
+--mask-eui64   8 --anonymize-method zeroize	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500:8900::
+--mask-eui64   0 --anonymize-method zeroize	2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4500::
 --anonymize-standard			2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:4509:a929:4291:c02d:5d15
 --anonymize-careful			2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:123:a909:a949:4291:c02d:5d13
 --anonymize-paranoid			2001:0db8:0123:4567:89ab:cdef:0123:4567=2001:db8:109:a909:a969:4291:c02d:5d1a
@@ -238,12 +275,59 @@ testscenarios_anonymization_options() {
 --mask-mac  20				12:34:56:78:9a:bc=12:34:50:00:00:00
 --mask-mac  16				12:34:56:78:9a:bc=12:34:00:00:00:00
 --mask-mac   8				12:34:56:78:9a:bc=12:00:00:00:00:00
---mask-mac   0				12:34:56:78:9a:bc=00:00:00:00:00:00
+--mask-mac   0 				12:34:56:78:9a:bc=02:00:00:00:00:00
 --mask-ipv4 24				2002:c002:f97f::211:32ff:fe13:956f=2002:c002:f900:9:a929:4291:4021:132d
 --mask-ipv4 24				2002:c000:0251::c000:0251=2002:c000:200:9:a929:4291:8c00:28
---mask-ipv4 24 --anonymize-method zeroise	2002:c000:0251::c000:0251=2002:c000:200::192.0.2.0
+--mask-ipv4 24 --anonymize-method zeroize	2002:c000:0251::c000:0251=2002:c000:200::192.0.2.0
 --anonymize-standard			2001:db8:0123:4567:0250:c2ff:fe86:2345=2001:db8:123:4509:a929:4291:5021:8621
 --anonymize-standard			2001:db8:0123:4567:0250:c286:2345:4567=2001:db8:123:4509:a929:4291:7021:8626
+# EUI-64: local
+--anonymize-preset zs --mask-eui64 0			12:34:56:78:9a:ff:ff:ff=02:00:00:00:00:00:00:00
+--anonymize-preset zs --mask-eui64 31			12:34:56:ff:ff:ff:ff:ff=12:34:56:fe:00:00:00:00
+--anonymize-preset zs --mask-eui64 32			12:34:56:ff:ff:ff:ff:ff=12:34:56:ff:00:00:00:00
+--anonymize-preset zs --mask-eui64 33			12:34:56:ff:ff:ff:ff:ff=12:34:56:ff:80:00:00:00
+--anonymize-preset zs --mask-eui64 55			12:34:56:78:9a:ff:ff:ff=12:34:56:78:9a:ff:fe:00
+--anonymize-preset zs --mask-eui64 56			12:34:56:78:9a:ff:ff:ff=12:34:56:78:9a:ff:ff:00
+--anonymize-preset zs --mask-eui64 57			12:34:56:78:9a:ff:ff:ff=12:34:56:78:9a:ff:ff:80
+--anonymize-preset zs --mask-eui64 58			12:34:56:78:9a:ff:ff:ff=12:34:56:78:9a:ff:ff:c0
+--anonymize-preset zs --mask-eui64 59			12:34:56:78:9a:ff:ff:ff=12:34:56:78:9a:ff:ff:e0
+--anonymize-preset zs --mask-eui64 60			12:34:56:78:9a:ff:ff:ff=12:34:56:78:9a:ff:ff:f0
+--anonymize-preset zs --mask-eui64 61			12:34:56:78:9a:ff:ff:ff=12:34:56:78:9a:ff:ff:f8
+--anonymize-preset zs --mask-eui64 62			12:34:56:78:9a:ff:ff:ff=12:34:56:78:9a:ff:ff:fc
+--anonymize-preset zs --mask-eui64 63			12:34:56:78:9a:ff:ff:ff=12:34:56:78:9a:ff:ff:fe
+--anonymize-preset zs --mask-eui64 64			12:34:56:78:9a:ff:ff:ff=12:34:56:78:9a:ff:ff:ff
+# EUI-48: local
+--anonymize-preset zs --mask-mac 0			12:34:56:78:9a:ff=02:00:00:00:00:00
+--anonymize-preset zs --mask-mac 31			12:34:56:ff:ff:ff=12:34:56:fe:00:00
+--anonymize-preset zs --mask-mac 32			12:34:56:ff:ff:ff=12:34:56:ff:00:00
+--anonymize-preset zs --mask-mac 33			12:34:56:ff:ff:ff=12:34:56:ff:80:00
+# EUI-64: global (OUI-24)
+--anonymize-preset zc		00:02:b3:ff:ff:ff:ff:ff=00:02:b3:00:00:00:00:00
+# EUI-64: global (OUI-24) expanded EUI-48
+--anonymize-preset zc		00:02:b3:ff:fe:ff:ff:ff=00:02:b3:ff:fe:00:00:00
+# EUI-64: global (OUI-36)
+--anonymize-preset zc		00:1b:c5:03:df:ff:ff:ff=00:1b:c5:03:d0:00:00:00
+# EUI-64: global (OUI-36) expanded EUI-48
+--anonymize-preset zc		00:1b:c5:ff:fe:03:df:ff=00:1b:c5:ff:fe:03:d0:00
+--anonymize-preset zc --mask-eui64 16 --mask-autoadjust no	00:1b:c5:ff:fe:03:df:ff=00:1b:00:00:00:00:00:00
+# EUI-48: global (OUI-24)
+--anonymize-preset zc		00:02:b3:ff:ff:ff=00:02:b3:00:00:00
+# EUI-48: global (OUI-36)
+--anonymize-preset zc		00:1b:c5:03:df:ff=00:1b:c5:03:d0:00
+--anonymize-preset zc --mask-mac 16 --mask-autoadjust no	00:1b:c5:03:df:ff=00:1b:00:00:00:00
+END
+}
+
+testscenarios_anonymization_options_kp() {
+	cat <<END | grep -v '^#'
+--anonymize-preset kp			46.244.223.233=242.222.34.63
+--anonymize-preset kp			2001:0a60:11e1:9501:e876:aee4:0721:e8ac=a909:16fa:9092:23ff:a909:4941::7
+--anonymize-preset kp			::1.2.3.4=::246.24.59.65
+--anonymize-preset kp			::ffff:1.2.3.4=::ffff:246.24.59.65
+--anonymize-preset kp			::1=::1
+--anonymize-preset kp			3ffe:831f:ce49:7601:8000:efff:af4a:86bf=3ffe:831f:ce49:7601:8000:ffff:a0b:f33a
+--anonymize-preset kp			64:ff9b::0102:0304=64:ff9b::f618:3b41
+--anonymize-preset kp			2001:0db8:0000:0000:81c0:0f3f:c807:1455=2001:db8::a909:4941:0:7
 END
 }
 
@@ -266,7 +350,6 @@ testscenarios_showinfo() {
 2001:db8:123:4509:a929:4291:7021:8626	OUI="Elsys AG"
 2001:db8:123:4509:a929:4291:7021:8626	EUI64_SCOPE=global
 2001:db8:11e0:6201:224:21ff:fe01:2345	EUI48_SCOPE=global
-2001:db8:11e0:6201:224:21ff:fe01:2345	OUI="MICRO-STAR INT'L CO., LTD."
 0123.4567.89ab				EUI48=01:23:45:67:89:ab
 01-23-45-67-89-ab			EUI48=01:23:45:67:89:ab
 012345-6789ab				EUI48=01:23:45:67:89:ab
@@ -274,5 +357,55 @@ testscenarios_showinfo() {
 c0a80102				IPV4=192.168.1.2
 0a010203				IPV4=10.1.2.3
 a010203					IPV4=10.1.2.3
+# non-anonymized IPv6 prefix
+2001:a60:113a:0123:0123:4567:89ab:cdef	IPV6_REGISTRY=RIPENCC
+# anonymized IPv6 prefix
+a909:16fa:9092:23ff:a909:4941::7	IPV6_COUNTRYCODE=DE
+a909:16fa:9092:23ff:a909:4941::7	IPV6_AS_NUM=8767
+a909:16fa:9092:23ff:a909:4941::7	IPV6_REGISTRY=RIPENCC
+# non-anonymized IPv4 address
+46.244.223.233				IPV4_REGISTRY=RIPENCC
+# anonymized IPv4 address
+242.222.34.63				IPV4_COUNTRYCODE=DE
+242.222.34.63				IPV4_AS_NUM=8767
+246.24.59.65				IPV4_COUNTRYCODE=AU
+::246.24.59.65				IPV4_COUNTRYCODE[246.24.59.65]=AU
+::ffff:246.24.59.65			IPV4_COUNTRYCODE[246.24.59.65]=AU
+END
+}
+
+testscenarios_showinfo_geoip() {
+	cat <<END | grep -v '^#'
+# non-anonymized IPv4 address
+46.244.223.233				GEOIP_COUNTRY_SHORT=DE
+46.244.223.233				IPV4_AS_NUM=8767		DB_IPV4_AS
+46.244.223.233				IPV4_REGISTRY=RIPENCC
+1.2.3.4					IPV4_COUNTRYCODE=AU
+::1.2.3.4				IPV4_COUNTRYCODE[1.2.3.4]=AU
+::ffff:1.2.3.4				IPV4_COUNTRYCODE[1.2.3.4]=AU
+# non-anonymized IPv6 prefix
+2001:a60:113a:0123:0123:4567:89ab:cdef	IPV6_COUNTRYCODE=DE
+2001:a60:113a:0123:0123:4567:89ab:cdef	IPV6_AS_NUM=8767		DB_IPV6_AS
+END
+}
+
+testscenarios_showinfo_ip2location() {
+	cat <<END | grep -v '^#'
+# non-anonymized IPv4 address
+46.244.223.233				IPV4_COUNTRYCODE=DE
+46.244.223.233				IP2LOCATION_COUNTRY_SHORT=DE
+# non-anonymized IPv6 prefix
+2001:a60:113a:0123:0123:4567:89ab:cdef	IPV6_COUNTRYCODE=DE
+2001:a60:113a:0123:0123:4567:89ab:cdef	IP2LOCATION_COUNTRY_SHORT=DE
+END
+}
+
+testscenarios_showinfo_anonymized_info() {
+	cat <<END | grep -v '^#'
+# IPv4 address
+1.2.3.4;;match;IPV4_ANON=246.24.59.65
+1.2.3.4;;key-word;IPV6CALC_FEATURES=ANON_KEEP-TYPE-ASN-CC
+1.2.3.4;--db-geoip-disable --db-ip2location-disable;match;IPV4_ANON=1.2.3.0
+1.2.3.4;--db-geoip-disable --db-ip2location-disable;key-no-word;IPV6CALC_FEATURES=ANON_KEEP-TYPE-ASN-CC
 END
 }
