@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6loganon.c
- * Version    : $Id: ipv6loganon.c,v 1.16 2013/05/12 07:23:12 ds6peter Exp $
+ * Version    : $Id: ipv6loganon.c,v 1.27 2013/10/30 20:04:25 ds6peter Exp $
  * Copyright  : 2007-2013 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
@@ -23,9 +23,12 @@
 #include "ipv6calchelp.h"
 #include "ipv6loganonhelp.h"
 
+#include "ipv6calcoptions.h"
+
 #include "libipv4addr.h"
 #include "libipv6addr.h"
 #include "libmac.h"
+#include "libeui64.h"
 
 #include "librfc1884.h"
 #include "librfc1886.h"
@@ -36,10 +39,11 @@
 #include "libeui64.h"
 #include "libieee.h"
 
+#include "../databases/lib/libipv6calc_db_wrapper.h"
+
 #define LINEBUFFER	16384
 
 long int ipv6calc_debug = 0;
-int flag_quiet = 1;
 int flag_nocache = 0;
 
 /* anonymization default values */
@@ -49,6 +53,11 @@ int mask_ipv6;
 int mask_iid;
 int mask_mac;
 
+/* features */
+int feature_zeroize = 1; // always supported
+int feature_anon    = 1; // always supported
+int feature_kp      = 0; // will be checked later
+
 
 /* prototypes */
 static int anonymizetoken(char *result, const char *token);
@@ -72,11 +81,34 @@ int	file_out_flush = 0;
 char	file_out_mode[NI_MAXHOST] = "";
 FILE	*FILE_OUT;
 
+
+void printversion_verbose(const int level) {
+	printversion();
+	fprintf(stderr, "\n");
+	ipv6calc_print_features_verbose(level);
+};
+
 /**************************************************/
 /* main */
 #define DEBUG_function_name "ipv6loganon/main"
 int main(int argc,char *argv[]) {
 	int i, lop, result;
+	uint32_t command = 0;
+
+	/* options */
+	struct option longopts[MAXLONGOPTIONS];
+	char   shortopts[NI_MAXHOST] = "";
+	int    longopts_maxentries = 0;
+
+	ipv6calc_quiet = 1; //default for ipv6loganon
+
+	/* initialize debug value from environment for bootstrap debugging */
+	ipv6calc_debug_from_env();
+
+	/* add options */
+	ipv6calc_options_add_common_anon(shortopts, sizeof(shortopts), longopts, &longopts_maxentries);
+	ipv6calc_options_add_common_basic(shortopts, sizeof(shortopts), longopts, &longopts_maxentries);
+	ipv6calc_options_add(shortopts, sizeof(shortopts), longopts, &longopts_maxentries, ipv6loganon_shortopts, ipv6loganon_longopts, MAXENTRIES_ARRAY(ipv6loganon_longopts));
 
 	/* default */
 	result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, "anonymize-standard");
@@ -86,30 +118,50 @@ int main(int argc,char *argv[]) {
 	};
 
 	/* Fetch the command-line arguments. */
-	while ((i = getopt_long(argc, argv, ipv6loganon_shortopts, ipv6loganon_longopts, &lop)) != EOF) {
+	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
+		if (ipv6calc_debug != 0) {
+			fprintf(stderr, "%s/%s: Parsing option: 0x%08x\n", __FILE__, __func__, i);
+		};
+
+		/* catch common options */
+		result = ipv6calcoptions_common_basic(i, optarg, longopts);
+		if (result == 0) {
+			// found
+			continue;
+		};
+
+		/* catch "common anon" options */
+		result = ipv6calcoptions_common_anon(i, optarg, longopts, &ipv6calc_anon_set);
+		if (result == 0) {
+			// found
+			continue;
+		};
+
 		switch (i) {
 			case -1:
 				break;
 
 			case 'v':
-				printversion();
-				exit(EXIT_FAILURE);
+				if ((command & CMD_printversion_verbose) != 0) {
+					// 3rd time '-v'
+					command |= CMD_printversion_verbose2;
+				} else if ((command & CMD_printversion) != 0) {
+					// 2nd time '-v'
+					command |= CMD_printversion_verbose;
+				} else {
+					command |= CMD_printversion;
+				};
 				break;
 
 			case 'V':
-				flag_quiet = 0;
+				ipv6calc_quiet = 0;
 				break;
 
 			case 'h':
 			case '?':
-				ipv6loganon_printhelp();
-				exit(EXIT_FAILURE);
+				command |= CMD_printhelp;
 				break;
 				
-			case 'd':
-				ipv6calc_debug = atol(optarg);
-				break;
-
 			case 'f':
 				file_out_flush = 1;
 				break;
@@ -150,94 +202,6 @@ int main(int argc,char *argv[]) {
 				flag_nocache = 1;
 				break;
 
-			case CMD_ANON_MASK_IID:
-				mask_iid = 1;
-				mask_iid = atoi(optarg);
-				if (mask_iid < 0 || mask_iid > 64) {
-					fprintf(stderr, " value for option 'mask-iid' out-of-range  [0-64]\n");
-					exit(EXIT_FAILURE);
-				};
-				ipv6calc_anon_set.mask_iid = mask_iid;
-				snprintf(ipv6calc_anon_set.name, sizeof(ipv6calc_anon_set.name) - 1, "%s", "custom");
-				break;
-
-			case CMD_ANON_MASK_IPV4:
-				mask_ipv4 = atoi(optarg);
-				if (mask_ipv4 < 0 || mask_ipv4 > 32) {
-					fprintf(stderr, " value for option 'mask-ipv4' out-of-range  [0-32]\n");
-					exit(EXIT_FAILURE);
-				};
-				ipv6calc_anon_set.mask_ipv4 = mask_ipv4;
-				snprintf(ipv6calc_anon_set.name, sizeof(ipv6calc_anon_set.name) - 1, "%s", "custom");
-				break;
-
-			case CMD_ANON_MASK_IPV6:
-				mask_ipv6 = atoi(optarg);
-				if (mask_ipv6 < 0 || mask_ipv6 > 64) {
-					fprintf(stderr, " value for option 'mask-ipv6' out-of-range  [0-64]\n");
-					exit(EXIT_FAILURE);
-				};
-				ipv6calc_anon_set.mask_ipv6 = mask_ipv6;
-				snprintf(ipv6calc_anon_set.name, sizeof(ipv6calc_anon_set.name) - 1, "%s", "custom");
-				break;
-
-			case CMD_ANON_MASK_MAC:
-				mask_mac = atoi(optarg);
-				if (mask_mac < 0 || mask_mac > 48) {
-					fprintf(stderr, " value for option 'mask-mac' out-of-range  [0-48]\n");
-					exit(EXIT_FAILURE);
-				};
-				ipv6calc_anon_set.mask_mac = mask_mac;
-				snprintf(ipv6calc_anon_set.name, sizeof(ipv6calc_anon_set.name) - 1, "%s", "custom");
-				break;
-
-			case CMD_ANON_PRESET_STANDARD:
-				result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, "as");
-				if (result != 0) {
-					fprintf(stderr, "major problem, ipv6calc anonymization preset not found: anonymize-standard\n");
-					exit(EXIT_FAILURE);
-				};
-				break;
-
-			case CMD_ANON_PRESET_CAREFUL:
-				result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, "ac");
-				if (result != 0) {
-					fprintf(stderr, "major problem, ipv6calc anonymization preset not found: anonymize-careful\n");
-					exit(EXIT_FAILURE);
-				};
-				break;
-
-			case CMD_ANON_PRESET_PARANOID:
-				result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, "ap");
-				if (result != 0) {
-					fprintf(stderr, "major problem, ipv6calc anonymization preset not found: anonymize-paranoid\n");
-					exit(EXIT_FAILURE);
-				};
-				break;
-
-			case CMD_ANON_PRESET_OPTION:
-				result = libipv6calc_anon_set_by_name(&ipv6calc_anon_set, optarg);
-				if (result != 0) {
-					fprintf(stderr, "major problem, ipv6calc anonymization preset not found: %s\n", optarg);
-					exit(EXIT_FAILURE);
-				};
-				break;
-
-			case CMD_ANON_METHOD_OPTION:
-				for (i = 0; i < sizeof(ipv6calc_anon_methods) / sizeof(s_ipv6calc_anon_methods); i++) {
-					if (strcmp(ipv6calc_anon_methods[i].name, optarg) == 0) {
-						ipv6calc_anon_set.method = ipv6calc_anon_methods[i].method;
-						snprintf(ipv6calc_anon_set.name, sizeof(ipv6calc_anon_set.name) -1, "%s", "custom");
-						break;
-					};
-				};
-
-				if (i == sizeof(ipv6calc_anon_methods) / sizeof(s_ipv6calc_anon_methods)) {
-					fprintf(stderr, "ipv6calc anonymization method not supported: %s\n", optarg);
-					exit(EXIT_FAILURE);
-				};
-				break;
-
 			default:
 				ipv6loganon_printinfo();
 				exit(EXIT_FAILURE);
@@ -247,6 +211,41 @@ int main(int argc,char *argv[]) {
 	argv += optind;
 	argc -= optind;
 
+	/* initialise database wrapper */
+	result = libipv6calc_db_wrapper_init();
+	if (result != 0) {
+		exit(EXIT_FAILURE);
+	};
+
+	/* check for KeepTypeAsnCC support */
+	if ((libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEASNCC_IPV4_REQ_DB) == 1) \
+	    && (libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEASNCC_IPV6_REQ_DB) == 1)) {
+		feature_kp = 1;
+	};
+
+	/* do work depending on selection */
+	DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "command=0x%08x", command);
+
+	if ((command & CMD_printhelp) != 0) {
+		ipv6loganon_printhelp();
+		exit(EXIT_FAILURE);
+	};
+
+	if ((command & CMD_printversion) != 0) {
+		if ((command & CMD_printversion_verbose) != 0) {
+			printversion_verbose(((command & CMD_printversion_verbose2) !=0) ? LEVEL_VERBOSE2 : LEVEL_VERBOSE);
+		} else {
+			printversion();
+		};
+		exit(EXIT_SUCCESS);
+	};
+
+	/* check requirements */
+	if (libipv6calc_anon_supported(&ipv6calc_anon_set) == 0) {
+		fprintf(stderr, "ipv6calc anonymization method not supported\n");
+		exit(EXIT_FAILURE);
+	};
+
 	if (file_out_flag == 1) {
 		if (ipv6calc_debug > 0) {
 			fprintf(stderr, "Output file specified: %s\n", file_out);
@@ -298,7 +297,7 @@ static void lineparser(void) {
 
 	ptrptr = &cptr;
 	
-	if (flag_quiet == 0) {
+	if (ipv6calc_quiet == 0) {
 		fprintf(stderr, "Expecting log lines on stdin\n");
 	};
 
@@ -314,7 +313,7 @@ static void lineparser(void) {
 		linecounter++;
 
 		if (linecounter == 1) {
-			if (flag_quiet == 0) {
+			if (ipv6calc_quiet == 0) {
 				fprintf(stderr, "Ok, proceeding stdin...\n");
 			};
 		};
@@ -387,7 +386,7 @@ static void lineparser(void) {
 		};
 	};
 
-	if (flag_quiet == 0) {
+	if (ipv6calc_quiet == 0) {
 		fprintf(stderr, "...finished\n");
 
 		if (flag_nocache == 0) {
@@ -411,9 +410,10 @@ static int anonymizetoken(char *resultstring, const char *token) {
 	int retval = 1, i;
 
 	/* used structures */
-	ipv6calc_ipv6addr ipv6addr;
-	ipv6calc_ipv4addr ipv4addr;
-	ipv6calc_macaddr  macaddr;
+	ipv6calc_ipv6addr  ipv6addr;
+	ipv6calc_ipv4addr  ipv4addr;
+	ipv6calc_macaddr   macaddr;
+	ipv6calc_eui64addr eui64addr;
 
 	if (ipv6calc_debug != 0) {
 		fprintf(stderr, "%s: Token: '%s'\n", DEBUG_function_name, token);
@@ -501,6 +501,10 @@ static int anonymizetoken(char *resultstring, const char *token) {
 			retval = addr_to_ipv4addrstruct(token, resultstring, &ipv4addr);
 			break;
 
+		case FORMAT_eui64:
+			retval = libeui64_addr_to_eui64addrstruct(token, resultstring, &eui64addr);
+			break;
+
 		case FORMAT_macaddr:
 			retval = addr_to_macaddrstruct(token, resultstring, &macaddr);
 			break;
@@ -530,14 +534,21 @@ static int anonymizetoken(char *resultstring, const char *token) {
 
 	} else if (ipv4addr.flag_valid == 1) {
 		/* anonymize IPv4 address according to settings */
-		libipv4addr_anonymize(&ipv4addr, ipv6calc_anon_set.mask_ipv4);
+		libipv4addr_anonymize(&ipv4addr, ipv6calc_anon_set.mask_ipv4, ipv6calc_anon_set.method);
 
 		/* convert IPv4 address structure to string */
 		libipv4addr_ipv4addrstruct_to_string(&ipv4addr, resultstring, 0);
 
+	} else if (eui64addr.flag_valid == 1) {
+		/* anonymize EUI-64C address according to settings */
+		libeui64_anonymize(&eui64addr, &ipv6calc_anon_set);
+
+		/* convert EUI-64 address structure to string */
+		libeui64_eui64addrstruct_to_string(&eui64addr, resultstring, 0);
+
 	} else if (macaddr.flag_valid == 1) {
 		/* anonymize MAC address according to settings */
-		libmacaddr_anonymize(&macaddr, ipv6calc_anon_set.mask_mac);
+		libmacaddr_anonymize(&macaddr, &ipv6calc_anon_set);
 
 		/* convert MAC address structure to string */
 		libmacaddr_macaddrstruct_to_string(&macaddr, resultstring, 0);
