@@ -2,11 +2,24 @@
 #
 # Project    : ipv6calc
 # File       : test_ipv6loganon.sh
-# Version    : $Id: test_ipv6loganon.sh,v 1.17 2013/04/07 17:52:29 ds6peter Exp $
+# Version    : $Id: test_ipv6loganon.sh,v 1.23 2013/10/30 20:04:25 ds6peter Exp $
 # Copyright  : 2007-2013 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test program for "ipv6loganon"
 
+if [ ! -x ./ipv6loganon ]; then
+	echo "Binary './ipv6loganon' missing or not executable"
+	exit 1
+fi
+
+# Test proper option definitions
+echo "Test proper option definition"
+./ipv6loganon -h >/dev/null
+if [ $? -ne 1 ]; then
+	echo "ERROR : something wrong in option definition"
+	exit 1
+fi
+
 testscenarios_standard() {
 # Address
 cat <<END | grep -v "^#"
@@ -115,7 +128,7 @@ if [ "$1" != "bulk" ]; then
 		echo "IN     : $input"
 		echo "CHECK  : $result"
 		# get result
-		output="`echo "$input" | ./ipv6loganon`"
+		output="`echo "$input" | ./ipv6loganon -q`"
 		echo "OUT    : $output"
 		retval=$?
 		if [ $retval -ne 0 ]; then
@@ -150,7 +163,7 @@ if [ "$1" != "bulk" ]; then
 			echo "OPTIONS: $options"
 			echo "CHECK  : $result"
 			# get result
-			output="`echo "$input" | ./ipv6loganon $options`"
+			output="`echo "$input" | ./ipv6loganon -q $options`"
 			echo "OUT    : $output"
 			retval=$?
 			if [ $retval -ne 0 ]; then
@@ -190,36 +203,42 @@ else
 fi
 
 if [ $retval -ne 0 ]; then
+	echo "ERROR : function tests failed"
 	exit 1
 fi
 
 
-echo "Run 'ipv6loganon' reliability tests..." >&2
-list="`testscenarios_standard | awk '{ print $1 }'`"
-list="$list
-`testscenarios_special | awk '{ print $1 }'`"
-sortlist="`echo "$list" | sort -u`"
-
-for entry in $sortlist; do
-	echo "DEBUG : test: $entry"
-	nonanonymized="`echo "$entry" | ../ipv6logstats/ipv6logstats -q`"
-	anonymized="`echo "$entry" | ./ipv6loganon | ../ipv6logstats/ipv6logstats -q`"
-
-	entry_anon="`echo "$entry" | ./ipv6loganon`"
-
-	if [ "$nonanonymized" != "$anonymized" ]; then
-		echo "ERROR : result not equal: $entry_anon"
-		echo "INFO  : non-anonymized statistics"
-		echo "$nonanonymized"
-		echo "INFO  : anonymized statistics"
-		echo "$anonymized"
-		exit 1
+run_loganon_reliability_tests() {
+	if [ ! -x ../ipv6logstats/ipv6logstats ]; then
+		echo "ERROR : missing binary: ../ipv6logstats/ipv6logstats (check build process)"
+		return 1
 	fi
-done
 
-echo "Run 'ipv6loganon' option tests..." >&2
-# Test Scenarios
-source ../ipv6calc/test_scenarios.sh
+	local options="$*"
+
+	echo "INFO  : run 'ipv6loganon' reliability tests with options: $options" >&2
+	list="`testscenarios_standard | awk '{ print $1 }'`"
+	list="$list
+	`testscenarios_special | awk '{ print $1 }'`"
+	sortlist="`echo "$list" | sort -u`"
+
+	for entry in $sortlist; do
+		echo "DEBUG : test: $entry"
+		nonanonymized="`echo "$entry" | ../ipv6logstats/ipv6logstats -q | grep -v "Time:"`"
+		anonymized="`echo "$entry" | ./ipv6loganon -q $options | ../ipv6logstats/ipv6logstats -q | grep -v "Time:"`"
+
+		entry_anon="`echo "$entry" | ./ipv6loganon -q $options`"
+
+		if [ "$nonanonymized" != "$anonymized" ]; then
+			echo "ERROR : result not equal: $entry_anon"
+			export anonymized
+			export nonanonymized
+			diff -u <(echo "$nonanonymized") <(echo "$anonymized")
+			echo "ERROR : result not equal between anonymized and non-anonymized statistics: $entry_anon"
+			return 1
+		fi
+	done
+}
 
 run_loganon_options_tests() {
 	echo "Run 'ipv6loganon' anonymization option tests..."
@@ -237,9 +256,9 @@ run_loganon_options_tests() {
 		input=${input_result/=*/}
 		result=${input_result/*=/}
 
-		command="echo $input | ./ipv6loganon $options"
+		command="echo $input | ./ipv6loganon -q $options"
 
-		result_real="`echo $input | ./ipv6loganon $options`"
+		result_real="`echo $input | ./ipv6loganon -q $options`"
 		if [ $? -ne 0 ]; then
 			echo "ERROR : command was not proper executed: $command"
 			exit 1
@@ -256,11 +275,75 @@ run_loganon_options_tests() {
 	done || return 1
 }
 
-run_loganon_options_tests
-retval=$?
+run_loganon_options_kp_tests() {
+	if ! ./ipv6loganon -vv 2>&1 | grep -q "Country4=1 Country6=1 ASN4=1 ASN6=1"; then
+		echo "NOTICE 'ipv6calc' has not required support for Country/ASN included, skip option kp tests..."
+		return 0
+	fi
+	echo "Run 'ipv6loganon' anonymization option kp tests..."
+	testscenarios_anonymization_options_kp | while read line; do
+		if [ -z "$line" ]; then
+			continue
+		fi
 
-if [ $retval -eq 0 ]; then
-	echo "All tests were successfully done!" >&2
+		options="`echo $line | awk '{ for ( i = 1; i < NF; i++) printf "%s ", $i }'`"
+		input_result="`echo $line | awk '{ print $NF }'`"
+
+		echo "DEBUG : options=$options"
+		echo "DEBUG : input_result=$input_result"
+
+		input=${input_result/=*/}
+		result=${input_result/*=/}
+
+		command="echo $input | ./ipv6loganon -q $options"
+
+		result_real="`echo $input | ./ipv6loganon -q $options`"
+		if [ $? -ne 0 ]; then
+			echo "ERROR : command was not proper executed: $command"
+			exit 1
+		fi
+
+		if [ "$result" != "$result_real" ]; then
+			echo "ERROR : result doesn't match on command: $command"
+			echo "ERROR : result is      : $result_real"
+			echo "ERROR : result expected: $result"
+			exit 1
+		else
+			echo "INFO  : $command -> test ok"
+		fi
+	done || return 1
+
+	run_loganon_reliability_tests "--anonymize-preset kp"
+	if [ $? -ne 0 ]; then
+		return 1
+	fi
+}
+
+
+#### Main
+
+run_loganon_reliability_tests
+if [ $? -ne 0 ]; then
+	echo "ERROR : run_loganon_reliability_tests failed"
+	exit 1
 fi
 
-exit $retval
+echo "INFO  : run 'ipv6loganon' option tests..." >&2
+# Test Scenarios
+source ../ipv6calc/test_scenarios.sh
+
+run_loganon_options_tests
+if [ $? -ne 0 ]; then
+	echo "ERROR : run_loganon_options_tests failed"
+	exit 1
+fi
+
+run_loganon_options_kp_tests
+if [ $? -ne 0 ]; then
+	echo "ERROR : run_loganon_options_kp_tests failed"
+	exit 1
+fi
+
+echo "All tests were successfully done!" >&2
+
+exit 0
