@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6logconv.h
- * Version    : $Id: ipv6logconv.h,v 1.7 2010/05/20 16:21:22 peter Exp $
- * Copyright  : 2002-2006 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6logconv.h,v 1.8 2013/11/04 20:55:00 ds6peter Exp $
+ * Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
  * License    : GNU GPL v2
  *
  * Information:
@@ -16,5 +16,9 @@
 /* LRU cache maximum size */
 #define CACHE_LRU_SIZE 200
 
+
+#define DEBUG_ipv6logconv_general      0x00000001l
+#define DEBUG_ipv6logconv_processing   0x00000002l
+
 /* prototyping */
 int cache_lru_limit;
