@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calccommands.h
- * Version    : $Id: ipv6calccommands.h,v 1.12 2013/03/30 18:03:45 ds6peter Exp $
- * Copyright  : 2002-2011 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calccommands.h,v 1.18 2013/10/31 21:24:46 ds6peter Exp $
+ * Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file containing commands for ipv6calc
@@ -12,10 +12,15 @@
 
 #define _ipv6calccommands_h_
 
+/* verbose levels */
+#define LEVEL_VERBOSE			0x1
+#define LEVEL_VERBOSE2			0x2
+
 /* command values */
 #define CMD_printhelp			0x0000001
 #define CMD_printversion		0x0000002
 #define CMD_printversion_verbose	0x0000020
+#define CMD_printversion_verbose2	0x0000040
 
 #define CMD_printexamples		0x0000004
 #define CMD_printoldoptions		0x0000008
@@ -46,7 +51,7 @@
 #define CMD_showinfo			0x0001001
 #define CMD_showinfotypes		0x0001002
 
-/* database options */
+/* database options (old) */
 #define DB_ip2location_ipv4		0x0002001
 #define DB_ip2location_ipv6		0x0002002
 #define DB_ip2location_ipv4_default	0x0002003
@@ -56,6 +61,15 @@
 #define DB_geoip_ipv4_default		0x0002013
 #define DB_geoip_ipv6_default		0x0002014
 
+/* database options (new) */
+#define DB_ip2location_disable		0x0002000
+#define DB_ip2location_dir		0x0002005
+#define DB_ip2location_lib		0x0002006
+
+#define DB_geoip_disable		0x0002010
+#define DB_geoip_dir			0x0002015
+#define DB_geoip_lib			0x0002016
+
 /* address anonymizer options */
 #define CMD_ANON_PRESET_STANDARD	0x0003001
 #define CMD_ANON_PRESET_CAREFUL		0x0003002
@@ -64,8 +78,10 @@
 #define CMD_ANON_PRESET_OPTION		0x000300f
 #define CMD_ANON_MASK_IPV4		0x0003010
 #define CMD_ANON_MASK_IPV6		0x0003011
-#define CMD_ANON_MASK_IID		0x0003012
+#define CMD_ANON_MASK_EUI64		0x0003012
 #define CMD_ANON_MASK_MAC		0x0003013
+#define CMD_ANON_MASK_AUTOADJUST	0x0003018
+#define CMD_ANON_MASK_IID		0x0003019	// deprecated
 
 /* 6rd options */
 #define CMD_6rd_prefix			0x0004001
