@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calchelp.c
- * Version    : $Id: ipv6calchelp.c,v 1.31 2013/05/12 07:23:12 ds6peter Exp $
+ * Version    : $Id: ipv6calchelp.c,v 1.50 2013/11/02 17:05:11 ds6peter Exp $
  * Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -18,6 +18,30 @@
 #include "ipv6calchelp.h"
 #include "config.h"
 
+#include "libieee.h"
+#include "databases/ieee-oui/dbieee_oui.h"
+#include "databases/ieee-iab/dbieee_iab.h"
+#include "databases/ieee-oui36/dbieee_oui36.h"
+#include "databases/ipv4-assignment/dbipv4addr_assignment.h"
+#include "databases/ipv6-assignment/dbipv6addr_assignment.h"
+#include "databases/lib/libipv6calc_db_wrapper.h"
+#include "databases/lib/libipv6calc_db_wrapper_GeoIP.h"
+#include "databases/lib/libipv6calc_db_wrapper_IP2Location.h"
+#include "databases/lib/libipv6calc_db_wrapper_BuiltIn.h"
+
+
+#ifdef SUPPORT_IP2LOCATION
+/* 
+ *  * API_VERSION is defined as a bareword in IP2Location.h, 
+ *   * we need this trick to stringify it. Blah.
+ *    */
+#define makestr(x) #x
+#define xmakestr(x) makestr(x)
+
+extern char* file_ip2location_ipv4;
+extern char* file_ip2location_ipv6;
+#endif
+
 /* to be defined in each application */
 extern void printversion(void);
 extern void printcopyright(void);
@@ -92,13 +116,13 @@ void printhelp_inputtypes(const uint32_t formatoptions) {
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) fprintf(stderr, "\n Available input types:\n");
 
 	/* run through matrix */
-	for (i = 0; i < (int) (sizeof(ipv6calc_formatmatrix) / sizeof(ipv6calc_formatmatrix[0])); i++) {
+	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatmatrix); i++) {
 		if (ipv6calc_debug != 0) {
 			fprintf(stderr, "Row %d: %08x - %08x\n", i, (unsigned int) ipv6calc_formatmatrix[i][0], (unsigned int) ipv6calc_formatmatrix[i][1]);
 		};
 		if (ipv6calc_formatmatrix[i][1] != 0) {
 			/* available for input, look for name now */
-			for (j = 0; j < (int) (sizeof(ipv6calc_formatstrings) / sizeof(ipv6calc_formatstrings[0])); j++) {
+			for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatstrings); j++) {
 				if (ipv6calc_debug != 0) {
 					fprintf(stderr, "Format-Row %d: %08x - %s - %s\n", j, (unsigned int) ipv6calc_formatstrings[j].number, ipv6calc_formatstrings[j].token, ipv6calc_formatstrings[j].explanation);
 				};
@@ -129,7 +153,7 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 	};
 
 	/* look for longest type definition */
-	for (j = 0; j < (int) (sizeof(ipv6calc_formatstrings) / sizeof(ipv6calc_formatstrings[0])); j++) {
+	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatstrings); j++) {
 		if (strlen(ipv6calc_formatstrings[j].token) > maxlen) {
 			maxlen = strlen(ipv6calc_formatstrings[j].token);
 		};
@@ -159,12 +183,12 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 	};
 
 	/* run through matrix */
-	for (j = 0; j < (int) (sizeof(ipv6calc_formatstrings) / sizeof(ipv6calc_formatstrings[0])); j++) {
+	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatstrings); j++) {
 		if (ipv6calc_debug != 0) {
 			fprintf(stderr, "Format-Row %d: %08x - %s - %s\n", j, (unsigned int) ipv6calc_formatstrings[j].number, ipv6calc_formatstrings[j].token, ipv6calc_formatstrings[j].explanation);
 		};
 
-		for (i = 0; i < (int) (sizeof(ipv6calc_formatmatrix) / sizeof(ipv6calc_formatmatrix[0])); i++) {
+		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatmatrix); i++) {
 			if ( (inputtype & ~ (FORMAT_auto | FORMAT_any) ) != 0 ) {
 				if (ipv6calc_formatmatrix[i][0] != inputtype) {
 					/* skip */
@@ -197,7 +221,7 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 
 
 /* list of action types */
-void printhelp_actiontypes(const uint32_t formatoptions) {
+void printhelp_actiontypes(const uint32_t formatoptions, const struct option longopts[]) {
 	int i, j, o, test = 2, has_options = 0;
 	size_t maxlen = 0;
 	char printformatstring[20], printformatstring2[20], printformatstring3[20];
@@ -234,7 +258,7 @@ void printhelp_actiontypes(const uint32_t formatoptions) {
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) fprintf(stderr, "\n Available action types:\n");
 
-	for (j = 0; j < (int) (sizeof(ipv6calc_actionstrings) / sizeof(ipv6calc_actionstrings[0])); j++) {
+	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_actionstrings); j++) {
 		if (ipv6calc_debug != 0) {
 			fprintf(stderr, "Format-Row %d: %08x - %s - %s\n", j, (unsigned int) ipv6calc_actionstrings[j].number, ipv6calc_actionstrings[j].token, ipv6calc_actionstrings[j].explanation);
 		};
@@ -248,7 +272,7 @@ void printhelp_actiontypes(const uint32_t formatoptions) {
 				};
 
 				/* search for defined options */
-				for (i = 0; i < (int) (sizeof(ipv6calc_actionoptionmap) / sizeof(ipv6calc_actionoptionmap[0])); i++) {
+				for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_actionoptionmap); i++) {
 					if (ipv6calc_debug != 0) {
 						fprintf(stderr, "Option %d\n", i);
 					};
@@ -264,17 +288,19 @@ void printhelp_actiontypes(const uint32_t formatoptions) {
 						};
 
 						/* run through options */
-						for (o = 0; o < (int) (sizeof(ipv6calc_longopts) / sizeof (ipv6calc_longopts[0])); o++) {
-							if ((ipv6calc_actionoptionmap[i][1] == ipv6calc_longopts[o].val)) {
+						o = 0;
+						while(longopts[o].name != NULL) {
+							if ((ipv6calc_actionoptionmap[i][1] == longopts[o].val)) {
 								has_options = 1;
 								if (test == 1) {	
-									fprintf(stderr, printformatstring3, "", ipv6calc_longopts[o].name);
-									if (ipv6calc_longopts[o].has_arg > 0) {
+									fprintf(stderr, printformatstring3, "", longopts[o].name);
+									if (longopts[o].has_arg > 0) {
 										fprintf(stderr, " ...");
 									};
 									fprintf(stderr, "\n");
 								};
 							};
+							o++;
 						};
 					};
 				};
@@ -291,85 +317,47 @@ void printhelp_actiontypes(const uint32_t formatoptions) {
 };
 
 
-/* print global help */
-void printhelp(void) {
-	printversion();
-	printcopyright();
-	fprintf(stderr, "\n");
-	fprintf(stderr, " General:\n");
+/* print global common help */
+void printhelp_common(void) {
 	fprintf(stderr, "  [-d|--debug <debug value>] : debug value (bitwise like)\n");
-	fprintf(stderr, "  [-q|--quiet]               : be more quiet (auto-enabled in pipe mode)\n");
-	fprintf(stderr, "  [-f|--flush]               : flush each line in pipe mode\n");
-	fprintf(stderr, "  -v                         : show version (and included features)\n");
-	fprintf(stderr, "  -v -v                      : show verbose version information\n");
-	fprintf(stderr, "\n");
-	fprintf(stderr, " Usage with new style options:\n");
-	fprintf(stderr, "  [--in|-I <input type>]   : specify input  type\n");
-	fprintf(stderr, "                             (default: autodetect)\n");
-	fprintf(stderr, "  [--out|-O <output type>] : specify output type\n");
-	fprintf(stderr, "                             (sometimes: autodetect)\n");
-	fprintf(stderr, "  [--action|-A <action>]   : specify action\n");
-	fprintf(stderr, "                             (default: format conversion, sometimes: autodetect)\n");
-	fprintf(stderr, "  [<format option> ...] : specify format options\n");
-	fprintf(stderr, "  <input data> [...]    : input data\n");
-	fprintf(stderr, "\n");
-	fprintf(stderr, "  Available input  types:  [-m] -I|--in     -?|-h|--help\n");
-	fprintf(stderr, "  Available output types:  [-m] -O|--out    -?|-h|--help\n");
-	fprintf(stderr, "  Available action types:  [-m] -A|--action -?|-h|--help\n");
-	fprintf(stderr, "\n");
-	fprintf(stderr, " Other usage:\n");
-	fprintf(stderr, "\n");
-	fprintf(stderr, "  --showinfo|-i [--machine_readable|-m] : show information about input data\n");
-	fprintf(stderr, "  --showinfo|-i --show_types            : show available types on '-m'\n");
+	fprintf(stderr, "                                can also be set IPV6CALC_DEBUG environment value\n");
+	fprintf(stderr, "  [-v|--version [-v [-v]]]   : version information (2 optional verbose levels)\n");
+	fprintf(stderr, "  [-h|--help|-?]             : this online help\n");
+
 #ifdef SUPPORT_IP2LOCATION
 	fprintf(stderr, "\n");
-	fprintf(stderr, "  [--db-ip2location-ipv4 <file>] : IP2Location IPv4 database file (optional)\n");
-	fprintf(stderr, "  [--db-ip2location-ipv6 <file>] : IP2Location IPv6 database file (optional)\n");
-#ifdef IP2LOCATION_DEFAULT_FILE_IPV4
-	fprintf(stderr, "  [--db-ip2location-ipv4-default|-L] : enable & use IP2Location IPv4 default database file (optional)\n");
-	fprintf(stderr, "                                        %s\n", IP2LOCATION_DEFAULT_FILE_IPV4);
-#endif
-#ifdef IP2LOCATION_DEFAULT_FILE_IPV6
-	fprintf(stderr, "  [--db-ip2location-ipv6-default|-L] : enable & use IP2Location IPv6 default database file (optional)\n");
-	fprintf(stderr, "                                        %s\n", IP2LOCATION_DEFAULT_FILE_IPV6);
+	fprintf(stderr, "  [--db-ip2location-disable        ] : IP2Location support disabled\n");
+	fprintf(stderr, "  [--db-ip2location-dir <directory>] : IP2Location database directory (default: %s)\n", ip2location_db_dir);
+#ifdef SUPPORT_IP2LOCATION_DYN
+	fprintf(stderr, "  [--db-ip2location-lib <file>]      : IP2Location library file (default: %s)\n", ip2location_lib_file);
 #endif
 #endif
+
 #ifdef SUPPORT_GEOIP
 	fprintf(stderr, "\n");
-	fprintf(stderr, "  [--db-geoip-ipv4 <file>]  : GeoIP IPv4 database file (optional)\n");
-#ifdef SUPPORT_GEOIP_V6
-	fprintf(stderr, "  [--db-geoip-ipv6 <file>]  : GeoIP IPv6 database file (optional)\n");
-#endif
-#ifdef GEOIP_DEFAULT_FILE_IPV4
-	fprintf(stderr, "  [--db-geoip-ipv4-default|-G] : enable & use GeoIP IPv4 default database file (optional)\n");
-	fprintf(stderr, "                                  %s\n", GEOIP_DEFAULT_FILE_IPV4);
-#endif
-#ifdef GEOIP_DEFAULT_FILE_IPV6
-#ifdef SUPPORT_GEOIP_V6
-	fprintf(stderr, "  [--db-geoip-ipv6-default|-G] : enable & use GeoIP IPv6 default database file (optional)\n");
-	fprintf(stderr, "                                  %s\n", GEOIP_DEFAULT_FILE_IPV6);
+	fprintf(stderr, "  [--db-geoip-disable              ] : GeoIP support disabled\n");
+	fprintf(stderr, "  [--db-geoip-dir       <directory>] : GeoIP database directory (default: %s)\n", geoip_db_dir);
+#ifdef SUPPORT_GEOIP_DYN
+	fprintf(stderr, "  [--db-geoip-lib       <file>]      : GeoIP library file (default: %s)\n", geoip_lib_file);
 #endif
 #endif
-#endif
-	fprintf(stderr, "\n");
-	fprintf(stderr, " To see old-style option use: --printoldoptions\n");
-	fprintf(stderr, "\n");
-
 	return;
 };
 
-void printhelp_oldoptions(void) {
-	int i;
+void printhelp_oldoptions(const struct option longopts[]) {
+	int i = 0;
 	
 	printversion();
 	printcopyright();
 	fprintf(stderr, " Usage with old style (shortcut) options (going obsolete):\n");
 	fprintf(stderr, "  <shortcut option> [<format option> ...] <input data> [...]\n");
 	fprintf(stderr, "\n");
-	for (i = 0; i < (int) (sizeof(ipv6calc_longopts) / sizeof(ipv6calc_longopts[0])); i++) {
-		if (ipv6calc_longopts[i].val >= CMD_shortcut_start && ipv6calc_longopts[i].val <= CMD_shortcut_end) {
-			fprintf(stderr, "  --%s\n", ipv6calc_longopts[i].name);
+
+	while(longopts[i].name != NULL) {
+		if (longopts[i].val >= CMD_shortcut_start && longopts[i].val <= CMD_shortcut_end) {
+			fprintf(stderr, "  --%s\n", longopts[i].name);
 		};
+		i++;
 	};
 	
 	fprintf(stderr, "\n");
@@ -557,7 +545,7 @@ void printhelp_output_dispatcher(const uint32_t outputtype) {
 	};
 	
 	/* looking for outtype */
-	for (i = 0; i < (int) (sizeof(ipv6calc_outputformatoptionmap) / sizeof(ipv6calc_outputformatoptionmap[0])); i++) {
+	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_outputformatoptionmap); i++) {
 		if (outputtype == ipv6calc_outputformatoptionmap[i][0]) {
 			if (ipv6calc_outputformatoptionmap[i][1] == 0) {
 				fprintf(stderr, " No format options supported\n");
@@ -572,7 +560,7 @@ void printhelp_output_dispatcher(const uint32_t outputtype) {
 			fprintf(stderr, " Available format options:\n");
 
 			/* run through format options */
-			for (j = 0; j < (int) (sizeof(ipv6calc_formatoptionstrings) / sizeof (ipv6calc_formatoptionstrings[0])); j++) {
+			for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatoptionstrings); j++) {
 				if ((ipv6calc_outputformatoptionmap[i][1] & ipv6calc_formatoptionstrings[j].number) != 0) {
 					fprintf(stderr, "  %s: %s\n", ipv6calc_formatoptionstrings[j].token, ipv6calc_formatoptionstrings[j].explanation);
 				};
@@ -627,7 +615,7 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 
 			fprintf(stderr, "  Available presets (shortcut names) [--anonymize-preset PRESET-NAME]:\n");
 
-			for (i = 0; i < sizeof(ipv6calc_anon_set_list) / sizeof(s_ipv6calc_anon_set); i++) {
+			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_anon_set_list); i++) {
 				snprintf(method_name, sizeof(method_name) - 1, "%s", "unknown"); // default
 
 				for (j = 0; j < sizeof(ipv6calc_anon_methods) / sizeof(s_ipv6calc_anon_methods); j++) {
@@ -637,15 +625,16 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 					};
 				};
 
-				fprintf(stderr, "   %-20s (%2s): mask-ipv6=%3d mask-ipv4=%2d mask-iid=%2d mask-mac=%2d method=%s\n", ipv6calc_anon_set_list[i].name, ipv6calc_anon_set_list[i].name_short, ipv6calc_anon_set_list[i].mask_ipv6, ipv6calc_anon_set_list[i].mask_ipv4, ipv6calc_anon_set_list[i].mask_iid, ipv6calc_anon_set_list[i].mask_mac, method_name);
+				fprintf(stderr, "   %-20s (%2s): mask-ipv6=%3d mask-ipv4=%2d mask-eui64=%2d mask-mac=%2d mask-autoadjust=%-3s method=%s\n", ipv6calc_anon_set_list[i].name, ipv6calc_anon_set_list[i].name_short, ipv6calc_anon_set_list[i].mask_ipv6, ipv6calc_anon_set_list[i].mask_ipv4, ipv6calc_anon_set_list[i].mask_eui64, ipv6calc_anon_set_list[i].mask_mac, (ipv6calc_anon_set_list[i].mask_autoadjust == 1) ? "yes" : "no", method_name);
 			};
 			fprintf(stderr, "\n");
 
 			fprintf(stderr, "  Custom control:\n");
-			fprintf(stderr, "  --mask-ipv4 <bits>     : mask IPv4 address [0-32] (even if occurs in IPv6 address)\n");
-			fprintf(stderr, "  --mask-ipv6 <bits>     : mask IPv6 prefix [0-64] (only applied to related address types)\n");
-			fprintf(stderr, "  --mask-iid  <bits>     : mask IPv6 interface identifiers [0-64]\n");
-			fprintf(stderr, "  --mask-mac  <bits>     : mask MAC address [0-48]\n");
+			fprintf(stderr, "  --mask-ipv4  <bits>     : mask IPv4 address [0-32] (even if occurs in IPv6 address)\n");
+			fprintf(stderr, "  --mask-ipv6  <bits>     : mask IPv6 prefix [0-64] (only applied to related address types)\n");
+			fprintf(stderr, "  --mask-eui64 <bits>     : mask EUI-64 address or IPv6 interface identifier [0-64]\n");
+			fprintf(stderr, "  --mask-mac   <bits>     : mask MAC address [0-48]\n");
+			fprintf(stderr, "  --mask-autoadjust yes|no: autoadjust mask to keep type/vendor information regardless of less given mask\n");
 
 			break;
 			
@@ -663,9 +652,11 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 
 		case ACTION_filter:
 			fprintf(stderr, " Filter given addresses from stdout by filter expression, e.g.\n");
-			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc -A filter -E iid-local\n");
-			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc -A filter -E iid-local,global-unicast\n");
-			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc -A filter -E ^iid-privacy\n");
+			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A filter] -E iid-local\n");
+			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A filter] -E iid-local,global-unicast\n");
+			fprintf(stderr, "  echo '2001:db8::1' | ipv6calc [-A filter] -E ^iid-randomy\n");
+			fprintf(stderr, "\n");
+			fprintf(stderr, " (note: since version 0.95.0 '-A filter' is autoselected if option '-E <filter expression>' is given)\n");
 			fprintf(stderr, "\n");
 			fprintf(stderr, "  IPv6 address filter tokens:\n");
 			fprintf(stderr, "   ipv6 ");
@@ -681,10 +672,116 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			};
 			fprintf(stderr, "\n");
 			fprintf(stderr, "\n");
-			fprintf(stderr, "  MAC address filter tokens:\n");
+			fprintf(stderr, "  EUI-48/MAC address filter tokens:\n");
+			fprintf(stderr, "   ");
+			fprintf(stderr, " IMPLEMENTATION MISSING");
+			fprintf(stderr, "\n");
+			fprintf(stderr, "\n");
+			fprintf(stderr, "  EUI-64 address filter tokens:\n");
 			fprintf(stderr, "   ");
 			fprintf(stderr, " IMPLEMENTATION MISSING");
 			fprintf(stderr, "\n");
 			break;
 	};
 };
+
+
+/***************************
+ * version information
+ * *************************/
+
+void ipv6calc_print_features(void) {
+#ifdef SUPPORT_IP2LOCATION
+	fprintf(stderr, " IP2Location");
+#endif
+#ifdef SUPPORT_GEOIP
+	fprintf(stderr, " GeoIP");
+#ifdef SUPPORT_GEOIP_V6
+	fprintf(stderr, " GeoIPv6");
+#endif
+#endif
+#ifdef SUPPORT_DB_IEEE
+	fprintf(stderr, " DB_IEEE");
+#endif
+#ifdef SUPPORT_DB_IPV4
+	fprintf(stderr, " DB_IPV4");
+#endif
+#ifdef SUPPORT_DB_IPV6
+	fprintf(stderr, " DB_IPV6");
+#endif
+};
+
+
+/* display features in verbose mode */
+void ipv6calc_print_features_verbose(const int level_verbose) {
+	char string[NI_MAXHOST];
+
+#ifdef SUPPORT_GEOIP
+#ifndef SUPPORT_GEOIP_DYN
+#ifdef SUPPORT_GEOIP_V6
+#if defined (SUPPORT_GEOIP_COUNTRY_CODE_BY_ADDR_V6) && defined (SUPPORT_GEOIP_COUNTRY_NAME_BY_ADDR_V6)
+	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 & IPv6 support\n");
+#else
+	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 & IPv6 support (in compatibility mode)\n");
+#endif
+#else
+	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 support only\n");
+#endif
+#ifdef SUPPORT_GEOIP_LIB_VERSION
+	fprintf(stderr, "GeoIP dynamic library version (on this system): %s\n", libipv6calc_db_wrapper_GeoIP_lib_version());
+#else
+	fprintf(stderr, "GeoIP dynamic library version (on this system): compiled without detection\n");
+#endif
+#else // SUPPORT_GEOIP_DYN
+#ifdef SUPPORT_GEOIP_V6
+	fprintf(stderr, "GeoIP support by dynamic library load, compiled with IPv4 & IPv6 support\n");
+#else
+	fprintf(stderr, "GeoIP support by dynamic library load, compiled with IPv4 support only\n");
+#endif // SUPPORT_GEOIP_DYN
+	fprintf(stderr, "GeoIP configured dynamic library file and version: %s %s\n", geoip_lib_file, libipv6calc_db_wrapper_GeoIP_lib_version());
+#endif
+
+	//TODO: list of GeoIP files
+#ifdef SUPPORT_GEOIP_V6
+	//TODO: list of GeoIP files
+#endif
+	libipv6calc_db_wrapper_GeoIP_wrapper_info(string, sizeof(string));
+	fprintf(stderr, "%s\n", string);
+#else
+	fprintf(stderr, "GeoIP support not enabled\n");
+#endif
+
+#ifdef SUPPORT_IP2LOCATION
+#ifndef SUPPORT_IP2LOCATION_DYN
+	fprintf(stderr, "IP2Location support enabled, compiled with API version: %s\n", xmakestr(API_VERSION));
+#else
+	fprintf(stderr, "IP2Location support by dynamic library load\n");
+	fprintf(stderr, "IP2Location configured dynamic library file and version: %s %s\n", ip2location_lib_file, libipv6calc_db_wrapper_IP2Location_lib_version());
+#endif
+	// TODO: show base directory
+	/*
+	if (file_ip2location_ipv4 != NULL && strlen(file_ip2location_ipv4) > 0) {
+		fprintf(stderr, "IP2Location IPv4 default file: %s\n", file_ip2location_ipv4);
+	} else {
+		fprintf(stderr, "IP2Location IPv4 default file: not configured\n");
+	};
+	if (file_ip2location_ipv6 != NULL && strlen(file_ip2location_ipv6) > 0) {
+		fprintf(stderr, "IP2Location IPv6 default file: %s\n", file_ip2location_ipv6);
+	} else {
+		fprintf(stderr, "IP2Location IPv6 default file: not configured\n");
+	};
+	*/
+#else
+	fprintf(stderr, "IP2Location support not enabled\n");
+#endif
+
+#ifdef SUPPORT_BUILTIN
+	libipv6calc_db_wrapper_BuiltIn_wrapper_info(string, sizeof(string));
+	fprintf(stderr, "%s\n", string);
+#else
+	fprintf(stderr, "BuiltIn support not enabled\n");
+#endif
+
+	libipv6calc_db_wrapper_print_db_info(level_verbose, "");
+};
+
