@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calctypes.h
- * Version    : $Id: ipv6calctypes.h,v 1.31 2013/03/30 18:03:45 ds6peter Exp $
+ * Version    : $Id: ipv6calctypes.h,v 1.36 2013/10/31 21:24:46 ds6peter Exp $
  * Copyright  : 2002-2013 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -138,7 +138,7 @@ typedef struct {
 	{ FORMAT_ipv4hex        , FORMAT_ipv4addr | FORMAT_ipv6addr | FORMAT_revipv4 | FORMAT_ipv4hex },
 	{ FORMAT_ipv4revhex     , FORMAT_ipv4addr | FORMAT_ipv6addr | FORMAT_revipv4 | FORMAT_ipv4hex },
 	{ FORMAT_mac            , FORMAT_eui64 },
-	{ FORMAT_eui64          , 0 },
+	{ FORMAT_eui64          , FORMAT_eui64 },
 	{ FORMAT_base85         , FORMAT_base85 | FORMAT_ipv6addr | FORMAT_revnibbles_int | FORMAT_revnibbles_arpa | FORMAT_bitstring | FORMAT_ifinet6 },
 	{ FORMAT_ifinet6        , FORMAT_base85 | FORMAT_ipv6addr | FORMAT_revnibbles_int | FORMAT_revnibbles_arpa | FORMAT_bitstring | FORMAT_ifinet6 },
 	{ FORMAT_iid_token      , FORMAT_iid_token },
@@ -255,6 +255,10 @@ typedef struct {
 #define ACTION_filter			(uint32_t) (1 << ACTION_NUM_filter)
 #define ACTION_undefined		(uint32_t) (1 << ACTION_NUM_undefined)
 
+#define ANON_METHOD_ANONYMIZE		1
+#define ANON_METHOD_ZEROIZE		2
+#define ANON_METHOD_KEEPTYPEASNCC	3
+
 typedef struct {
 	const uint32_t number;
 	const char *token;
@@ -292,16 +296,17 @@ typedef struct {
 	char name_short[3];
 	int mask_ipv4;
 	int mask_ipv6;
-	int mask_iid;
+	int mask_eui64;
 	int mask_mac;
-	int method;	// 1=anonymize, 2=zeroize
+	int mask_autoadjust;
+	int method;	// 1=anonymize, 2=zeroize, 3=keep type asn countrycode
 } s_ipv6calc_anon_set;
 
 /* anonymization methods */
 typedef struct {
-	char name[32];
-	int method;
-	char description[128];
+	const char name[32];
+	const int method;
+	const char description[128];
 } s_ipv6calc_anon_methods;
 
 #endif
