@@ -1,7 +1,7 @@
 /*
- * Project    : ipv6calc/lib
+ * Project    : ipv6calc
  * File       : libipv6addr.h
- * Version    : $Id: libipv6addr.h,v 1.64 2013/05/12 07:34:04 ds6peter Exp $
+ * Version    : $Id: libipv6addr.h,v 1.74 2013/10/24 19:05:04 ds6peter Exp $
  * Copyright  : 2001-2013 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
@@ -21,7 +21,7 @@
 /* IPv6 anonymization */
 /* 
  * IID anonymization is done by replacing with related information (64-bit)
- * xxxx:xxxx:xxxx:xxxx
+ * xxxx:xxxx:xxxx:xxxC  (C = 4-bit checksum)
  *
  * a9p9 4941 0000 000C  -> RFC 4941 anonymized privacy extension Interface ID
  *
@@ -42,17 +42,29 @@
  * a9p9 4843 0000 000C  -> RFC 4843 anonymized ORCHID hash
  *
  * SLA/NLA prefix part anonymization is done by replacing with pattern a909a909
- *   p = number of nibbles anonymized
+ *   p = number of nibbles anonymized in prefix
+ *   		0 : no nibble of prefix is anonymized
+ *   		f : Prefix anonymization with method=kp
+ *
+ * Prefix anonymization in case of method=kp: p=0x0f
+ * a909:ccca:aaaa:aaaC  (C = 4-bit checksum)
+ *                      ccc      -> 10-bit Country Code mapping [A-Z]*[A-Z0-9] (936)
+ *                                   0x3FF = unknown country
+ *                                   0x000-0x3A7: c1= c / 36, c2 = c % 36
+ *                      aaaaaaaa -> 32-bit ASN
  */
 #define ANON_TOKEN_VALUE_00_31		(uint32_t) 0xa9090000u
 #define ANON_TOKEN_MASK_00_31		(uint32_t) 0xff0f0000u
 
+#define ANON_IID_PREFIX_NIBBLES_MASK	(uint32_t) 0x0000000fu
+#define ANON_IID_PREFIX_NIBBLES_SHIFT	20
+
 #define ANON_CHECKSUM_MASK_32_63	(uint32_t) 0x0000000fu
 
-#define ANON_IID_PRIVACY_VALUE_00_31	(uint32_t) 0x00004941u
-#define ANON_IID_PRIVACY_MASK_00_31	(uint32_t) 0x0000ffffu
-#define ANON_IID_PRIVACY_VALUE_32_63	(uint32_t) 0x00000000u
-#define ANON_IID_PRIVACY_MASK_32_63	(uint32_t) 0xfffffff0u
+#define ANON_IID_RANDOM_VALUE_00_31	(uint32_t) 0x00004941u
+#define ANON_IID_RANDOM_MASK_00_31	(uint32_t) 0x0000ffffu
+#define ANON_IID_RANDOM_VALUE_32_63	(uint32_t) 0x00000000u
+#define ANON_IID_RANDOM_MASK_32_63	(uint32_t) 0xfffffff0u
 
 #define ANON_IID_STATIC_VALUE_00_31	(uint32_t) 0x00004291u
 #define ANON_IID_STATIC_MASK_00_31	(uint32_t) 0x0000ffffu
@@ -112,6 +124,41 @@
 #define ANON_CHECKSUM_FLAG_CREATE	1
 #define ANON_CHECKSUM_FLAG_VERIFY	2
 
+// Prefix anonymization on method=kp
+#define ANON_METHOD_KEEPTYPEASNCC_IPV6_REQ_DB	(IPV6CALC_DB_IPV6_TO_CC | IPV6CALC_DB_IPV6_TO_AS)
+
+#define ANON_PREFIX_CCINDEX_DWORD	0
+#define ANON_PREFIX_CCINDEX_SHIFT	4
+#define ANON_PREFIX_CCINDEX_MASK	0x3ff
+#define ANON_PREFIX_CCINDEX_XOR		0x0
+
+#define ANON_PREFIX_ASN32_MSB_DWORD	0
+#define ANON_PREFIX_ASN32_MSB_SHIFT	0
+#define ANON_PREFIX_ASN32_MSB_AMOUNT	4
+#define ANON_PREFIX_ASN32_MSB_MASK	((1 << ANON_PREFIX_ASN32_MSB_AMOUNT) - 1)
+#define ANON_PREFIX_ASN32_MSB_XOR	0x0000000a
+
+#define ANON_PREFIX_ASN32_LSB_DWORD	1
+#define ANON_PREFIX_ASN32_LSB_SHIFT	4
+#define ANON_PREFIX_ASN32_LSB_AMOUNT	28
+#define ANON_PREFIX_ASN32_LSB_MASK	((1 << ANON_PREFIX_ASN32_LSB_AMOUNT) - 1)
+#define ANON_PREFIX_ASN32_LSB_XOR	0x09090000
+
+#define ANON_PREFIX_FLAGS_DWORD		0
+#define ANON_PREFIX_FLAGS_SHIFT		14
+#define ANON_PREFIX_FLAGS_MASK		0x3
+#define ANON_PREFIX_FLAGS_XOR		0x0
+
+#define ANON_PREFIX_TOKEN_DWORD		0
+#define ANON_PREFIX_TOKEN_SHIFT		16
+#define ANON_PREFIX_TOKEN_MASK		0xffff
+#define ANON_PREFIX_TOKEN_XOR		0x0
+#define ANON_PREFIX_TOKEN_VALUE		0xa909		// fix
+
+// Payload selector
+#define ANON_PREFIX_PAYLOAD_CCINDEX	1
+#define ANON_PREFIX_PAYLOAD_ASN32	2
+
 
 /* IPv6 address storage structure */
 typedef struct {
@@ -143,17 +190,19 @@ typedef struct {
 	float hexdigit;
 	float lls_residual;		// lls: linear least square
 	int   digit_blocks[16];		// block length of same digit
+	int   digit_blocks_hexdigit[16];// hex digits used in blocks of same digit
 	int   digit_amount[16]; 	// amount of digits
 	int   digit_delta[31];  	// delta of digits
 	int   digit_delta_amount;  	// amount of delta of digits
 } s_iid_statistics;
 
-/* IID privacy limits */
-// this filter values detects 999.744 from 1.000.000 generated privacy extension IIDs (256 are not detected)
+/* IID random limits */
+// this filter values detects 999.744 from 1.000.000 generated random (using privacy extension) IIDs (256 are not detected)
 /*@unused@*/ static const s_iid_statistics s_iid_statistics_ok_min = {
 	0.249,		// fits to 100% of 1 million tested
 	6.275,		// fits to 100% of 1 million tested
 	{  4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},	// fit to 100% of 1 million tested
+	{  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},	// fit to 100% of 1 million tested
 	{  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},	// default
 	{  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, // default
 	6	// fit to 1 million
@@ -163,6 +212,7 @@ typedef struct {
 	2.5,		// fits to 1 million - 90 tested (100%: 4.016)
 	26.042,		// fits to 100% of 1 million tested
 	{ 16, 6, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},	// fit to 1 million - 3 tested
+	{  2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2},	// TODO
 	{  7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7},	// fit to 1 million - 38 tested
 	{  3, 4, 3, 3, 4, 5, 4, 5, 5, 5, 6, 6, 6, 7, 7, 6, 6, 7, 6, 6, 6, 5, 5, 5, 4, 4, 4, 4, 4, 3, 2},	// fit to 1 million
 	15	// fit to 1 million
@@ -200,7 +250,7 @@ typedef struct {
 #define IPV6_ADDR_UNICAST			(uint32_t) 0x00000001U	
 #define IPV6_ADDR_MULTICAST			(uint32_t) 0x00000002U	
 #define IPV6_ADDR_ANYCAST			(uint32_t) 0x00000004U
-
+#define IPV6_ADDR_ANONYMIZED_PREFIX		(uint32_t) 0x00000008U	/* anonymized IPv6 address (prefix) */
 
 #define IPV6_ADDR_LOOPBACK			(uint32_t) 0x00000010U
 #define IPV6_ADDR_LINKLOCAL			(uint32_t) 0x00000020U
@@ -217,7 +267,7 @@ typedef struct {
 #define IPV6_ADDR_MAPPED			(uint32_t) 0x00001000U
 #define IPV6_ADDR_RESERVED			(uint32_t) 0x00002000U	/* reserved address space */
 #define IPV6_ADDR_ULUA				(uint32_t) 0x00004000U	/* Unique Local Unicast Address */
-#define IPV6_ADDR_ANONYMIZED			(uint32_t) 0x00008000U	/* anonymized IPv6 address */
+#define IPV6_ADDR_ANONYMIZED_IID		(uint32_t) 0x00008000U	/* anonymized IPv6 address (IID) */
 
 #define IPV6_NEW_ADDR_6TO4			(uint32_t) 0x00010000U
 #define IPV6_NEW_ADDR_6BONE			(uint32_t) 0x00020000U
@@ -234,11 +284,15 @@ typedef struct {
 #define IPV6_NEW_ADDR_LINKLOCAL_TEREDO		(uint32_t) 0x04000000U
 #define IPV6_NEW_ADDR_NAT64			(uint32_t) 0x08000000U	/* RFC 6052 */
 
-#define IPV6_NEW_ADDR_IID_PRIVACY		(uint32_t) 0x10000000U	/* RFC 4941 (ex 3041) */
+#define IPV6_NEW_ADDR_IID_RANDOM		(uint32_t) 0x10000000U	/* possible RFC 4941 (ex 3041) */
 #define IPV6_NEW_ADDR_IID			(uint32_t) 0x20000000U	/* IPv6 address with IID inside */
 #define IPV6_NEW_ADDR_IID_LOCAL			(uint32_t) 0x40000000U	/* IPv6 address with local generated IID */
 #define IPV6_NEW_ADDR_IID_GLOBAL		(uint32_t) 0x80000000U	/* IPv6 address with global IID */
 
+#define IPV6_ADDR_HAS_PUBLIC_IPV4		(IPV6_NEW_ADDR_NAT64 | IPV6_NEW_ADDR_6TO4 | IPV6_NEW_ADDR_TEREDO | IPV6_ADDR_COMPATv4 | IPV6_ADDR_MAPPED)
+#define IPV6_ADDR_HAS_PUBLIC_IPV4_IN_PREFIX	(IPV6_NEW_ADDR_6TO4 | IPV6_NEW_ADDR_TEREDO)
+#define IPV6_ADDR_HAS_PUBLIC_IPV4_IN_IID	(IPV6_NEW_ADDR_NAT64 | IPV6_NEW_ADDR_TEREDO | IPV6_ADDR_COMPATv4 | IPV6_ADDR_MAPPED | IPV6_NEW_ADDR_6TO4_MICROSOFT)
+
 /* text representations */
 /*@unused@*/ static const s_type ipv6calc_ipv6addrtypestrings[] = {
 	{ IPV6_ADDR_ANY			, "unknown" },
@@ -252,7 +306,8 @@ typedef struct {
 	{ IPV6_ADDR_MAPPED		, "mapped" },
 	{ IPV6_ADDR_RESERVED		, "reserved" },
 	{ IPV6_ADDR_ULUA		, "unique-local-unicast" },
-	{ IPV6_ADDR_ANONYMIZED		, "anonymized" },
+	{ IPV6_ADDR_ANONYMIZED_IID	, "anonymized-iid" },
+	{ IPV6_ADDR_ANONYMIZED_PREFIX	, "anonymized-prefix" },
 	{ IPV6_NEW_ADDR_6TO4		, "6to4" },
 	{ IPV6_NEW_ADDR_6BONE		, "6bone" },
 	{ IPV6_NEW_ADDR_AGU		, "global-unicast" },
@@ -264,7 +319,7 @@ typedef struct {
 	{ IPV6_NEW_ADDR_ORCHID		, "orchid" },
 	{ IPV6_NEW_ADDR_LINKLOCAL_TEREDO, "link-local-teredo" },
 	{ IPV6_NEW_ADDR_NAT64		, "nat64" },
-	{ IPV6_NEW_ADDR_IID_PRIVACY	, "iid-privacy" },
+	{ IPV6_NEW_ADDR_IID_RANDOM	, "iid-random" },
 	{ IPV6_NEW_ADDR_IID		, "iid" },
 	{ IPV6_NEW_ADDR_IID_LOCAL	, "iid-local" },
 	{ IPV6_NEW_ADDR_IID_GLOBAL	, "iid-global" },
@@ -277,15 +332,17 @@ typedef struct {
 
 
 /* Registries */
-#define IPV6_ADDR_REGISTRY_6BONE	0x01
-#define IPV6_ADDR_REGISTRY_IANA		0x02
-#define IPV6_ADDR_REGISTRY_APNIC	0x03
-#define IPV6_ADDR_REGISTRY_ARIN		0x04
-#define IPV6_ADDR_REGISTRY_RIPE		0x05
-#define IPV6_ADDR_REGISTRY_LACNIC	0x06
-#define IPV6_ADDR_REGISTRY_AFRINIC	0x07
-#define IPV6_ADDR_REGISTRY_RESERVED	0x0e
-#define IPV6_ADDR_REGISTRY_UNKNOWN	0x0f
+#include "libipv6calc.h"
+
+#define IPV6_ADDR_REGISTRY_6BONE	REGISTRY_6BONE
+#define IPV6_ADDR_REGISTRY_IANA		REGISTRY_IANA
+#define IPV6_ADDR_REGISTRY_APNIC	REGISTRY_APNIC
+#define IPV6_ADDR_REGISTRY_ARIN		REGISTRY_ARIN
+#define IPV6_ADDR_REGISTRY_RIPE		REGISTRY_RIPE
+#define IPV6_ADDR_REGISTRY_LACNIC	REGISTRY_LACNIC
+#define IPV6_ADDR_REGISTRY_AFRINIC	REGISTRY_AFRINIC
+#define IPV6_ADDR_REGISTRY_RESERVED	REGISTRY_RESERVED
+#define IPV6_ADDR_REGISTRY_UNKNOWN	REGISTRY_UNKNOWN
 
 typedef struct {
 	const int number;
@@ -339,11 +396,14 @@ extern int  identifier_to_ipv6addrstruct(const char *addrstring, char *resultstr
 extern int  tokenlsb64_to_ipv6addrstruct(const char *addrstring, char *resultstring, ipv6calc_ipv6addr *ipv6addrp);
 extern int  libipv6addr_ipv6addrstruct_to_tokenlsb64(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const uint32_t formatoptions);
 
-extern void libipv6addr_anonymize(ipv6calc_ipv6addr *ipv6addrp, const s_ipv6calc_anon_set *ipv6calc_anon_set);
+extern int      libipv6addr_anonymize(ipv6calc_ipv6addr *ipv6addrp, const s_ipv6calc_anon_set *ipv6calc_anon_set);
 extern uint32_t ipv6addr_get_payload_anonymized_iid(const ipv6calc_ipv6addr *ipv6addrp, const uint32_t typeinfo);
+extern int      ipv6addr_get_payload_anonymized_prefix(const ipv6calc_ipv6addr *ipv6addrp, const int payload_selector, uint32_t *result_ptr);
 
-extern int ipv6addr_privacyextensiondetection(const ipv6calc_ipv6addr *ipv6addrp, s_iid_statistics *variancesp);
+extern int ipv6addr_iidrandomdetection(const ipv6calc_ipv6addr *ipv6addrp, s_iid_statistics *variancesp);
 
-extern int ipv6addr_filter(const ipv6calc_ipv6addr *ipv6addrp, const s_ipv6calc_filter_ipv6addr *filter);
-extern int ipv6addr_filter_parse(s_ipv6calc_filter_ipv6addr *filter, const char *token);
+extern int  ipv6addr_filter(const ipv6calc_ipv6addr *ipv6addrp, const s_ipv6calc_filter_ipv6addr *filter);
+extern int  ipv6addr_filter_parse(s_ipv6calc_filter_ipv6addr *filter, const char *token);
 extern void ipv6addr_filter_clear(s_ipv6calc_filter_ipv6addr *filter);
+
+extern int  libipv6addr_get_included_ipv4addr(const ipv6calc_ipv6addr *ipv6addrp, ipv6calc_ipv4addr *ipv4addrp, const int selector);
