@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv6calc.c
- * Version    : $Id: libipv6calc.c,v 1.31 2013/05/12 07:23:12 ds6peter Exp $
+ * Version    : $Id: libipv6calc.c,v 1.36 2013/10/30 20:04:25 ds6peter Exp $
  * Copyright  : 2001-2013 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -20,6 +20,7 @@
 #include "librfc2874.h"
 #include "librfc1886.h"
 
+#include "../databases/lib/libipv6calc_db_wrapper.h"
 
 /*
  * function converts chars in a string to upcase
@@ -520,23 +521,17 @@ int libipv6calc_anon_set_by_name(s_ipv6calc_anon_set *ipv6calc_anon_set, const c
 	int i;
 
 	if (strlen(name) == 0) {
-		fprintf(stderr, "Name of anonyimization set is empty\n");
+		fprintf(stderr, "Name of anonymization set is empty\n");
 		return 1;
 	};
 
-	if ( (ipv6calc_debug) != 0 ) {
-		fprintf(stderr, "%s/%s: search for anonymization set with name: %s\n", __FILE__, __func__, name);
-	};
+	DEBUGPRINT_WA(DEBUG_libipv6calc, "search for anonymization set with name: %s", name);
 
 	for (i = 0; i < sizeof(ipv6calc_anon_set_list) / sizeof(s_ipv6calc_anon_set); i++) {
-		if ( (ipv6calc_debug) != 0 ) {
-			fprintf(stderr, "%s/%s: compare name: %s ? %s\n", __FILE__, __func__, name, ipv6calc_anon_set_list[i].name);
-		};
+		DEBUGPRINT_WA(DEBUG_libipv6calc, "compare name: %s ? %s", name, ipv6calc_anon_set_list[i].name);
 
 		if ((strcmp(name, ipv6calc_anon_set_list[i].name) == 0) || (strcmp(name, ipv6calc_anon_set_list[i].name_short) == 0)) {
-			if ( (ipv6calc_debug) != 0 ) {
-				fprintf(stderr, "%s/%s: hit name: %s = %s\n", __FILE__, __func__, name, ipv6calc_anon_set_list[i].name);
-			};
+			DEBUGPRINT_WA(DEBUG_libipv6calc, "hit name: %s = %s", name, ipv6calc_anon_set_list[i].name);
 
 			memcpy(ipv6calc_anon_set, &ipv6calc_anon_set_list[i], sizeof(s_ipv6calc_anon_set));
 			return 0;
@@ -546,6 +541,27 @@ int libipv6calc_anon_set_by_name(s_ipv6calc_anon_set *ipv6calc_anon_set, const c
 	return 1;
 };
 
+
+/*
+ * get name of anonymization settings
+ *
+ * in : s_ipv6calc_anon_set = anonymization set
+ * return: char *
+ */
+const char *libipv6calc_anon_method_name(const s_ipv6calc_anon_set *ipv6calc_anon_set) {
+	int i;
+
+	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_anon_methods); i++) {
+		if (ipv6calc_anon_methods[i].method == ipv6calc_anon_set->method) {
+			return(ipv6calc_anon_methods[i].name);
+			break;
+		};
+	};
+
+	return(NULL);
+};
+
+
 /*
  * create string of anonymization settings
  *
@@ -554,17 +570,66 @@ int libipv6calc_anon_set_by_name(s_ipv6calc_anon_set *ipv6calc_anon_set, const c
  * return: void
  */
 void libipv6calc_anon_infostring(char *string, const int stringlength, const s_ipv6calc_anon_set *ipv6calc_anon_set) {
-	char method_name[32] = "unknown";
-	int i;
+	const char *method_name = libipv6calc_anon_method_name(ipv6calc_anon_set);
 
-	for (i = 0; i < sizeof(ipv6calc_anon_methods) / sizeof(s_ipv6calc_anon_methods); i++) {
-		if (ipv6calc_anon_methods[i].method == ipv6calc_anon_set->method) {
-			snprintf(method_name, sizeof(method_name) - 1, "%s", ipv6calc_anon_methods[i].name);
+	snprintf(string, stringlength - 1, "set=%s,mask-ipv6=%d,mask-ipv4=%d,mask-eui64=%d,mask-mac=%d,method=%s", ipv6calc_anon_set->name, ipv6calc_anon_set->mask_ipv6, ipv6calc_anon_set->mask_ipv4, ipv6calc_anon_set->mask_eui64, ipv6calc_anon_set->mask_mac, (method_name == NULL ? "unknown" : method_name));
+
+	return;
+};
+
+
+/*
+ * check whether anonymization method is supported
+ *
+ * in : s_ipv6calc_anon_set = anonymization set
+ * return:
+ *   2: special check succeeded
+ *   1: no special checks needed
+ *   0: not supported
+ */
+int libipv6calc_anon_supported(const s_ipv6calc_anon_set *ipv6calc_anon_set) {
+	/* check requirements */
+	if (ipv6calc_anon_set->method == ANON_METHOD_KEEPTYPEASNCC) {
+		// check for support
+		if (libipv6calc_db_wrapper_has_features(ANON_METHOD_KEEPTYPEASNCC_IPV4_REQ_DB | ANON_METHOD_KEEPTYPEASNCC_IPV6_REQ_DB) == 1) {
+			return(2);
+		} else {
+			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_CC) != 1) {
+				fprintf(stderr, "ipv6calc anonymization method not supported, missing included/available database: IPv4->CountryCode (GeoIP)\n");
+			};
+			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV6_TO_CC) != 1) {
+				fprintf(stderr, "ipv6calc anonymization method not supported, missing included/available database: IPv6->CountryCode (GeoIP)\n");
+			};
+			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_AS) != 1) {
+				fprintf(stderr, "ipv6calc anonymization method not supported, missing included/available database: IPv4->AutonomousSystemNumber (GeoIP)\n");
+			};
+			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV6_TO_AS) != 1) {
+				fprintf(stderr, "ipv6calc anonymization method not supported, missing included/available database: IPv6->AutonomousSystemNumber (GeoIP)\n");
+			};
+			return(0);
+		};
+	} else {
+		return(1);
+	};
+};
+
+
+/*
+ * return pointer to registry name by number
+ */
+const char *libipv6calc_registry_string_by_num(const int registry) {
+	int j = -1, i;
+	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_registries); i++ ) {
+		if (ipv6calc_registries[i].number == registry) {
+			j = i;
 			break;
 		};
 	};
 
-	snprintf(string, stringlength - 1, "set=%s,mask-ipv6=%d,mask-ipv4=%d,mask-iid=%d,mask-mac=%d,method=%s", ipv6calc_anon_set->name, ipv6calc_anon_set->mask_ipv6, ipv6calc_anon_set->mask_ipv4, ipv6calc_anon_set->mask_iid, ipv6calc_anon_set->mask_mac, method_name);
+	if (j == -1) {
+		fprintf(stderr, "ERROR - undefined registry number: %d (this should not happen)\n", registry);
+		exit(1);
+	};
 
-	return;
+	return(ipv6calc_registries[j].token);
 };
